(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='WolframDesktop 11.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       161,          7]
NotebookDataLength[    131179,       3435]
NotebookOptionsPosition[    112106,       3118]
NotebookOutlinePosition[    113709,       3160]
CellTagsIndexPosition[    113440,       3151]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Tables for addition and subtraction with better use of the place value system\
\>", "Title",ExpressionUUID->"9d9298ae-42bb-4d91-83fa-9aae849dd2e6"],

Cell["\<\
Thomas Colignatus
http://thomascool.eu
April 2 and major update May 5 2018\
\>", "Text",ExpressionUUID->"6a77c6a2-b695-4f51-921d-1fd0dccb1a48"],

Cell["\[Copyright] Thomas Cool CC-BY-NC-ND", "Text",ExpressionUUID->"80e295ba-2beb-41b2-a15a-127c56b93040"],

Cell[TextData[StyleBox["Abstract",
 FontWeight->"Bold"]], "Text",ExpressionUUID->"0b53733d-72a9-4178-b36a-041c26bdf534"],

Cell["\<\
This notebook presents tables for addition and subtraction that have a better \
use of the place value system. The method is already used in Holland for \
addition in levels but this notebook extends for addition in differences and \
subtraction in levels and differences. The method is only intended for an \
intermediate stage in teaching before addition and subtraction are mentally \
fully automated. For example 99 + 21 can be added per digit position. To keep \
digits in the range [0, 9] we remove underflow or overflow. We work from \
right to left, since the numbers come from India and Arabia. Then we get 99 + \
21 \[Rule] {9, 9} + {2, 1} = {11, 10} = {11, 10} + {1, -10} = {12, 0} = {0, \
12, 0} + {1, -10, 0} = {1, 2, 0} \[Rule] 120. Compared to existing methods: \
(1) This method does not change the original sum. (2) The workflow is into a \
single direction. (3) Allowing positions to have values outside the [0 , 9] \
range focuses attention upon the place value. (4) There is a unity of \
approach to both addition and subtraction. The method fits within the US \
Common Core when we tell kids that a step with {1, -10} represents the \
subtraction 1 \[Times] 10 - 10 \[Times] 1 = 0. It would be more fundamental \
to adapt the curriculum for negative numbers though. Routines to create such \
tables for addition and subtraction are available in a package. Obviously \
pupils in elementary school must master the method by hand, but the package \
allows for examples and checking. \
\>", "Text",ExpressionUUID->"5b53d446-c2c9-4903-852e-b01cb2ce59fb"],

Cell[TextData[StyleBox["Keywords",
 FontWeight->"Bold"]], "Text",ExpressionUUID->"b32d6f50-f283-4760-8499-c7d1a15888dd"],

Cell["\<\
Mathematics Education, Addition, Subtraction, Place Value System, Negative \
Numbers, Common Core, Mathematica, Wolfram language, Programming, Package\
\>", "Text",ExpressionUUID->"24d19483-4d60-4bd0-9d51-75844fad6d97"],

Cell[TextData[StyleBox["MSC2010",
 FontWeight->"Bold"]], "Text",ExpressionUUID->"19e09a36-9bca-4349-af3d-051d8d1930ac"],

Cell["97M70 Mathematics education. Behavioral and social sciences", "Text",ExpressionUUID->"d9c872a4-6194-49df-a529-ee063a5ed647"],

Cell[TextData[StyleBox["Cloud",
 FontWeight->"Bold"]], "Text",ExpressionUUID->"14954c9b-e428-4ebb-9375-b9071453aabd"],

Cell["This notebook with package is also available at: ", "Text",ExpressionUUID->"502a014d-a95c-4f79-aed7-a99cf3c48de0"],

Cell["\<\
(1)  http://community.wolfram.com/groups/-/m/t/1313408 (though the latter \
displays the earlier version in html and a short community title)\
\>", "Text",ExpressionUUID->"8d148d52-8bfc-44ea-b899-050d53a53119"],

Cell["\<\
(2) https://www.wolframcloud.com/objects/thomas-cool/MathEd/2018-04-02-\
AdditionTable-and-SubtractionTable.nb (same link but update notebook and \
package)\
\>", "Text",ExpressionUUID->"773fe3fa-ea8c-45cf-8a67-3d3686958bf2"],

Cell["\<\
(3) https://zenodo.org/record/1241350 or DOI 10.5281/zenodo.1241350   \
\>", "Text",ExpressionUUID->"5c9dc5de-7005-4cd8-909e-3a470e9dcaf3"],

Cell[CellGroupData[{

Cell["Contents", "Subsection",ExpressionUUID->"966bcf2a-714b-4eaa-96df-f1d09eb69f56"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". Introduction"
}], "Subsubsection",ExpressionUUID->"a097d6f4-5538-45e1-bf30-24ce731521d5"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". Discussion"
}], "Subsubsection",ExpressionUUID->"ab58aed4-ee32-45b3-ba03-398f959a2f78"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". With steps of differences"
}], "Subsubsection",ExpressionUUID->"20f5d55c-d057-42bd-8c4b-d017ad841dd8"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". With steps in levels"
}], "Subsubsection",ExpressionUUID->"87d584a6-6c56-44d7-b9a1-f6e5855ba911"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". Calculation strategy"
}], "Subsubsection",ExpressionUUID->"605c6bb6-1c52-4df0-8b56-18e13805e4fb"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". Subtraction in given order or with more numbers"
}], "Subsubsection",ExpressionUUID->"600b6c7d-ad10-46a0-93d2-f2e05b56c4a8"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". When the routines are overly complex"
}], "Subsubsection",ExpressionUUID->"9d0a6e8f-3e97-4a2e-bbf5-1d81907c3188"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". Comparison with Common Core and existing methods"
}], "Subsubsection",ExpressionUUID->"6ed4aaf7-fd4f-4aab-b2a7-0532ae0129ae"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". Some additional features"
}], "Subsubsection",ExpressionUUID->"db4859f1-d16e-4d97-b498-5aaa31a66fc1"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". The routines"
}], "Subsubsection",ExpressionUUID->"5508aa4e-75a4-4711-aa07-8aaf78ca7067"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". Conclusions"
}], "Subsubsection",ExpressionUUID->"3e7adb97-6778-488b-aea3-990292d67e61"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". Literature"
}], "Subsubsection",ExpressionUUID->"36a4cd99-103c-466e-825e-3c72128cf995"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Start (subsection for the initialisation packages)", "Subsection",ExpressionUUID->"38ffa996-0056-4372-9550-8e878fe08c99"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "Cool`MathEd`AdditionTable`"}], " ", "package"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "*******************************************)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{":", "Author", ":", " ", 
    RowBox[{"Thomas", " ", "Cool"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{":", "Copyright", ":", " ", 
    RowBox[{"Copyright", " ", "2018", " ", "Thomas", " ", "Cool"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Package", " ", "Version"}], ":", " ", "2.0"}], ",", " ", 
    RowBox[{
    "March", " ", "31", " ", "and", " ", "May", " ", "5", " ", "2018"}]}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{":", 
    RowBox[{"Mathematica", " ", "Version"}], ":", "11.2"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{":", "Keywords", ":"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{":", "Limitation", ":"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{":", "License", ":", " ", 
     RowBox[{"see", " ", 
      RowBox[{"http", ":"}]}]}], "//", 
    RowBox[{
     RowBox[{
      RowBox[{"thomascool", ".", "eu"}], "/", "TheEconomicsPack"}], "/", 
     RowBox[{"index", ".", "html"}]}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"BeginPackage", "[", "\"\<Cool`MathEd`AdditionTable`\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"AdditionTable", "::", "usage"}], " ", "=", 
     "\"\<AdditionTable[n__Integer] gives a table that adds the integers, \
that must be positive, using the place value system. The integers are added \
per digit position, and each overflow generates a new line in the \
table\\nAdditionTable[{n__Integer}] is another input format\\nOptions are \
passed on to ToSingleDigitsTable. Default there is Differences -> True \
(default); otherwise levels\\nWhen all integers are in [0, 9] then there is a \
warning that the routine is overly complex for such a case\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SubtractionTable", "::", "usage"}], " ", "=", 
     "\"\<SubtractionTable[n, m] gives a table for n - m, for n > m > 0, \
using the place value system. The integers are subtracted per digit position, \
and each underflow generates a new line in the table. If n < m then the \
routine switches the order. When subtracting a block of numbers, perhaps \
first add the numbers that must be subtracted, so that subtraction only \
applies to n - m\\nSubtractionTable[n__Integer] (for more than 2) or \
SubtractionTable[{n__Integer}] cannot switch the order though. Integers must \
be positive\\nOptions are passed on to ToSingleDigitsTable. Default there is \
Differences -> True (default); otherwise levels\\nWhen all integers are in \
[0, 9] then there is a warning that the routine is overly complex for such a \
case\>\""}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"MixedAdditionTable", "::", "usage"}], " ", "=", 
     "\"\<MixedAdditionTable[n__Integer] (for more than 2) or \
MixedAdditionTable[{n__Integer}] adds positive or negative integers. Options \
are passed on to ToSingleDigitsTable. Default there is Differences -> True \
(default); otherwise levels\\nWhen all integers are in [0, 9] then there is a \
warning that the routine is overly complex for such a case\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"TableOfBasicAddition", "::", "usage"}], " ", "=", " ", 
     "\"\<TableOfBasicAddition[n:0, m:10] gives i + j in the range [n, m] for \
values Abs[i + j] <= Max[Abs[n], Abs[m]], and n and m may be negative. \
Elements x within the table show j = x - i. Options are passed on to \
TableForm\>\""}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SquareTableOfAddition", "::", "usage"}], " ", "=", " ", 
     "\"\<SquareTableOfAddition[n:0, m:10] gives the addition of i + j, both \
in the range [n, m], that may be negative. Elements x within the table show j \
= x - i. Options are passed on to TableForm\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ToSingleDigitsTable", "::", "usage"}], " ", "=", " ", 
     "\"\<ToSingleDigitsTable[vec] decomposes the place value \
vector.\\nToSingleDigitsTable[\\\"Tested\\\", vec, table] complements the \
table. The test is on the proper length of vec for the table. The routine is \
called by AdditionTable, SubtractionTable and MixedAdditionTable for \
completion, and its option setting controls their output. Default option is \
Differences -> True; otherwise levels\>\""}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ToSingleDigits", "::", "usage"}], " ", "=", " ", 
     "\"\<ToSingleDigits[vec] multiplies the elements with 10^pos, counting \
pos from 0 from right to left\>\""}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ToSingleDigits", "[", 
     RowBox[{"lis_List", "?", "VectorQ"}], "]"}], " ", ":=", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"max", ",", " ", "powers"}], "}"}], ",", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"max", " ", "=", " ", 
        RowBox[{"Length", "[", "lis", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"powers", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"10", "^", "x"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"x", ",", "  ", 
            RowBox[{"max", "-", "1"}], ",", " ", "0", ",", " ", 
            RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"lis", " ", ".", " ", "powers"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SquareTableOfAddition", "[", 
     RowBox[{
      RowBox[{"n_Integer:", "0"}], ",", " ", 
      RowBox[{"m_Integer:", "10"}], ",", " ", "opts___Rule"}], "]"}], " ", ":=",
     " ", "\[IndentingNewLine]", 
    RowBox[{"TableForm", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"k", "=", " ", 
         RowBox[{"i", "+", " ", "j"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "m", ",", " ", "n", ",", " ", 
          RowBox[{"-", "1"}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", "n", ",", "m"}], "}"}]}], "]"}], ",", "opts", 
      ",", " ", 
      RowBox[{"TableHeadings", " ", "->", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"m", ",", " ", "n", ",", " ", 
           RowBox[{"-", "1"}]}], "]"}], ",", " ", 
         RowBox[{"Range", "[", 
          RowBox[{"n", ",", " ", "m"}], "]"}]}], "}"}]}], ",", " ", 
      RowBox[{"TableSpacing", " ", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{"1", ",", " ", "1.5"}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TableOfBasicAddition", "[", 
     RowBox[{
      RowBox[{"n_Integer:", "0"}], ",", " ", 
      RowBox[{"m_Integer:", "10"}], ",", " ", "opts___Rule"}], "]"}], " ", ":=",
     " ", "\[IndentingNewLine]", 
    RowBox[{"TableForm", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"k", "=", " ", 
          RowBox[{"i", "+", " ", "j"}]}], ";", " ", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Abs", "[", "k", "]"}], " ", "\[LessEqual]", " ", 
            RowBox[{"Max", "[", 
             RowBox[{
              RowBox[{"Abs", "[", "n", "]"}], " ", ",", " ", 
              RowBox[{"Abs", "[", "m", "]"}]}], "]"}]}], ",", " ", "k", ",", 
           " ", "\"\<\>\""}], "]"}]}], ",", "  ", 
        RowBox[{"{", 
         RowBox[{"j", ",", "m", ",", " ", "n", ",", " ", 
          RowBox[{"-", "1"}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", "n", ",", "m"}], "}"}]}], "]"}], ",", "opts", 
      ",", " ", 
      RowBox[{"TableHeadings", " ", "->", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"m", ",", " ", "n", ",", " ", 
           RowBox[{"-", "1"}]}], "]"}], ",", " ", 
         RowBox[{"Range", "[", 
          RowBox[{"n", ",", " ", "m"}], "]"}]}], "}"}]}], ",", " ", 
      RowBox[{"TableSpacing", " ", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{"1", ",", " ", "1.5"}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"AdditionTable", "::", "two"}], "=", " ", 
     "\"\<Addition of `1` number ?\>\""}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"AdditionTable", "::", "pos"}], " ", "=", " ", 
     "\"\<Numbers `1` must be positive\>\""}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"AdditionTable", "::", "lss"}], " ", "=", " ", 
     "\"\<Numbers all less than 10: routine is overly complex\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AdditionTable", "[", 
     RowBox[{"n__Integer", ",", " ", "opts___Rule"}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"AdditionTable", "[", 
     RowBox[{
      RowBox[{"{", "n", "}"}], ",", " ", "opts"}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AdditionTable", "[", 
     RowBox[{
      RowBox[{"{", "n__Integer", "}"}], ",", " ", "opts___Rule"}], "]"}], 
    "  ", ":=", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "nd", ",", " ", "max", ",", " ", "line", ",", " ", "res", ",", " ", 
        "tab", ",", "  ", "outcome", ",", "lis", ",", "m", ",", " ", "sel", 
        ",", " ", "t"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"lis", " ", "=", " ", 
        RowBox[{"{", "n", "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"m", " ", "=", " ", 
        RowBox[{"Length", "[", "lis", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"m", " ", "<", " ", "2"}], ",", " ", 
         RowBox[{
          RowBox[{"Message", "[", 
           RowBox[{
            RowBox[{"AdditionTable", "::", "two"}], ",", " ", "m"}], "]"}], 
          ";", " ", 
          RowBox[{"Return", "[", 
           RowBox[{"{", "n", "}"}], "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"sel", " ", "=", " ", 
        RowBox[{"Select", "[", 
         RowBox[{"lis", ",", " ", 
          RowBox[{
           RowBox[{"#", " ", "<", " ", "0"}], "&"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", "}"}], " ", "=!=", " ", "sel"}], ",", "  ", 
         RowBox[{
          RowBox[{"Message", "[", 
           RowBox[{
            RowBox[{"AdditionTable", "::", "pos"}], ",", " ", "sel"}], "]"}], 
          ";", 
          RowBox[{"Return", "[", "$Failed", "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"And", " ", "@@", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"#", " ", "<", " ", "10"}], " ", "&"}], "  ", "/@", "  ",
             "lis"}], ")"}]}], ",", " ", 
         RowBox[{"Message", "[", 
          RowBox[{"AdditionTable", "::", "lss"}], "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"nd", "=", " ", 
        RowBox[{"IntegerDigits", " ", "/@", " ", "lis"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"outcome", " ", "=", " ", 
        RowBox[{"IntegerDigits", "[", 
         RowBox[{"Total", "[", "lis", "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"max", " ", "=", " ", 
        RowBox[{"Length", "[", "outcome", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tab", "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"t", " ", "=", " ", "#"}], ";", " ", 
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Length", "[", "t", "]"}], " ", "=!=", " ", "max"}], 
              ",", " ", 
              RowBox[{"PrependTo", "[", 
               RowBox[{"t", ",", " ", "0"}], "]"}]}], "]"}], ";", " ", "t"}], 
           ")"}], "&"}], " ", "/@", " ", "nd"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"Total", " ", "/@", " ", 
         RowBox[{"Transpose", "[", "tab", "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"line", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{"\"\<+\>\"", ",", " ", 
          RowBox[{"{", 
           RowBox[{"i", ",", " ", "max"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"tab", ",", " ", "line"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"tab", ",", "  ", "res"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"ToSingleDigitsTable", "[", 
        RowBox[{
        "\"\<Tested\>\"", ",", "res", ",", " ", "tab", ",", " ", "opts"}], 
        "]"}]}]}], "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"used", "\[IndentingNewLine]", "split"}], " ", "=", " ", 
      RowBox[{"IntegerDigits", "[", "elem", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"change", " ", "=", " ", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{"split", ",", " ", 
         RowBox[{"-", "1"}]}], "]"}], " ", "~", "Join", "~", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Last", "[", "split", "]"}], " ", "-", " ", "elem"}], "}"}], 
       " ", "~", "Join", "~", " ", "rhs"}]}], ";"}], "\[IndentingNewLine]", 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SubtractionTable", "::", "two"}], "=", " ", 
     "\"\<Subtraction of `1` number ?\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"SubtractionTable", "::", "pos"}], " ", "=", " ", 
     "\"\<Numbers `1` must be positive\>\""}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SubtractionTable", "::", "ord"}], " ", "=", " ", 
     "\"\<Order switched into `1` - `2`\>\""}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SubtractionTable", "::", "lss"}], " ", "=", " ", 
     "\"\<Numbers all less than 10: routine is overly complex\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SubtractionTable", "[", 
     RowBox[{"n_Integer", ",", " ", "m_Integer", ",", " ", "opts___Rule"}], 
     "]"}], " ", ":=", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"n", " ", ">", " ", "0"}], " ", "&&", " ", 
            RowBox[{"m", " ", ">", " ", "0"}]}], ")"}]}], ",", " ", 
         RowBox[{
          RowBox[{"Message", "[", 
           RowBox[{
            RowBox[{"SubtractionTable", "::", "pos"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"n", ",", " ", "m"}], "}"}]}], "]"}], ";", 
          RowBox[{"Return", "[", "$Failed", "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"And", " ", "@@", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"#", " ", "<", " ", "10"}], " ", "&"}], "  ", "/@", "  ", 
            RowBox[{"{", 
             RowBox[{"m", ",", " ", "n"}], "}"}]}], ")"}]}], ",", " ", 
         RowBox[{"Message", "[", 
          RowBox[{"SubtractionTable", "::", "lss"}], "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", " ", 
        RowBox[{
         RowBox[{"n", "  ", "\[GreaterEqual]", " ", "m"}], ",", " ", 
         RowBox[{"SubtractionTable", "[", 
          RowBox[{"True", ",", " ", "n", ",", " ", "m", ",", " ", "opts"}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Message", "[", 
           RowBox[{
            RowBox[{"SubtractionTable", "::", "ord"}], ",", " ", "m", ",", 
            " ", "n"}], "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"SubtractionTable", "[", 
           RowBox[{"True", ",", " ", "m", ",", " ", "n", ",", " ", "opts"}], 
           "]"}]}]}], "]"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SubtractionTable", "[", 
     RowBox[{
     "True", ",", " ", "n_Integer", ",", " ", "m_Integer", ",", " ", 
      "opts___Rule"}], "]"}], " ", ":=", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "nd", ",", " ", "md", ",", " ", "max", ",", " ", "line", ",", "  ", 
        "res", ",", " ", "tab", ",", "  ", "outcome"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"outcome", " ", "=", " ", 
        RowBox[{"IntegerDigits", "[", 
         RowBox[{"n", "-", " ", "m"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"nd", "=", " ", 
        RowBox[{"IntegerDigits", "[", "n", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"md", " ", "=", " ", 
        RowBox[{"IntegerDigits", "[", "m", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"max", " ", "=", " ", 
        RowBox[{"Max", "[", 
         RowBox[{"Length", " ", "/@", " ", 
          RowBox[{"{", 
           RowBox[{"nd", ",", " ", "md", ",", " ", "outcome"}], "}"}]}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"line", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{"\"\<-\>\"", ",", " ", 
          RowBox[{"{", 
           RowBox[{"i", ",", " ", "max"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "nd", "]"}], " ", "=!=", " ", "max"}], ",", 
         " ", 
         RowBox[{"PrependTo", "[", 
          RowBox[{"nd", ",", " ", "0"}], "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "md", "]"}], " ", "=!=", " ", "max"}], ",", 
         " ", 
         RowBox[{"PrependTo", "[", 
          RowBox[{"md", ",", " ", "0"}], "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"nd", " ", "-", " ", "md"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tab", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{"nd", ",", " ", "md", ",", " ", "line", ",", " ", "res"}], 
         "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "largest", " ", "minus", " ", "smallest", " ", "always", " ", 
         "generates", " ", "a", " ", "nonnegative", " ", "outcome"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"ToSingleDigitsTable", "[", 
        RowBox[{
        "\"\<Tested\>\"", ",", "res", ",", " ", "tab", ",", " ", "opts"}], 
        "]"}]}]}], "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"at", " ", "the", " ", "most", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"MemberQ", "[", 
        RowBox[{"digits", ",", " ", "elem"}], "]"}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"change", " ", "=", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", " ", "10"}], "}"}], " ", "~", "Join", 
          "~", " ", "rhs"}]}], ";"}]}], "\[IndentingNewLine]"}]}], "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SubtractionTable", "[", 
     RowBox[{"n__Integer", ",", " ", "opts___Rule"}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"SubtractionTable", "[", 
     RowBox[{
      RowBox[{"{", "n", "}"}], ",", " ", "opts"}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SubtractionTable", "[", 
     RowBox[{
      RowBox[{"{", "n__Integer", "}"}], ",", " ", "opts___Rule"}], "]"}], " ",
     ":=", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "lis", ",", " ", "m", ",", " ", "sel", ",", " ", "nd", ",", " ", "max",
         ",", " ", "line", ",", "  ", "res", ",", " ", "tab", ",", " ", 
        "outcome", ",", " ", "difq", ",", " ", "first", ",", " ", "sign", ",",
         " ", "t"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"lis", " ", "=", " ", 
        RowBox[{"{", "n", "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"m", " ", "=", " ", 
        RowBox[{"Length", "[", "lis", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"m", " ", "<", " ", "2"}], ",", " ", 
         RowBox[{
          RowBox[{"Message", "[", 
           RowBox[{
            RowBox[{"SubtractionTable", "::", "two"}], ",", " ", "m"}], "]"}],
           ";", " ", 
          RowBox[{"Return", "[", 
           RowBox[{"{", "n", "}"}], "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"sel", " ", "=", " ", 
        RowBox[{"Select", "[", 
         RowBox[{"lis", ",", " ", 
          RowBox[{
           RowBox[{"#", " ", "<", " ", "0"}], "&"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", "}"}], " ", "=!=", " ", "sel"}], ",", "  ", 
         RowBox[{
          RowBox[{"Message", "[", 
           RowBox[{
            RowBox[{"SubtractionTable", "::", "pos"}], ",", " ", "sel"}], 
           "]"}], ";", 
          RowBox[{"Return", "[", "$Failed", "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"And", " ", "@@", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"#", " ", "<", " ", "10"}], " ", "&"}], "  ", "/@", "  ",
             "lis"}], ")"}]}], ",", " ", 
         RowBox[{"Message", "[", 
          RowBox[{"SubtractionTable", "::", "lss"}], "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"difq", " ", "=", " ", 
        RowBox[{
         RowBox[{"Differences", " ", "/.", " ", 
          RowBox[{"{", "opts", "}"}]}], " ", "/.", "  ", 
         RowBox[{"Options", "[", "SubtractionTable", "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"first", " ", "=", " ", 
        RowBox[{"First", "[", "lis", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"res", "=", " ", 
        RowBox[{"Rest", "[", "lis", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"outcome", " ", "=", " ", 
        RowBox[{"first", " ", "-", " ", 
         RowBox[{"Total", "[", "res", "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"sign", "=", " ", 
        RowBox[{"Sign", "[", "outcome", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"max", " ", "=", " ", 
        RowBox[{"Max", "[", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"Abs", "[", "lis", "]"}], ",", " ", 
           RowBox[{"Abs", "[", "outcome", "]"}]}], "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", 
        RowBox[{"maximal", " ", "number", " ", "involved"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"max", " ", "=", " ", 
        RowBox[{"Length", "[", 
         RowBox[{"IntegerDigits", "[", "max", "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"nd", "=", " ", 
        RowBox[{"IntegerDigits", " ", "/@", " ", "lis"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"outcome", " ", "=", " ", 
        RowBox[{"IntegerDigits", "[", "outcome", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"tab", "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"t", " ", "=", " ", "#"}], ";", " ", 
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Length", "[", "t", "]"}], " ", "=!=", " ", "max"}], 
              ",", " ", 
              RowBox[{"PrependTo", "[", 
               RowBox[{"t", ",", " ", "0"}], "]"}]}], "]"}], ";", " ", "t"}], 
           ")"}], "&"}], " ", "/@", " ", "nd"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"first", " ", "=", " ", 
        RowBox[{"First", "[", "tab", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"Rest", "[", "tab", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"first", " ", "-", "  ", 
         RowBox[{"(", 
          RowBox[{"Total", " ", "/@", " ", 
           RowBox[{"Transpose", "[", "res", "]"}]}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"line", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{"\"\<-\>\"", ",", " ", 
          RowBox[{"{", 
           RowBox[{"i", ",", " ", "max"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"tab", ",", " ", "line"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"tab", ",", " ", "res"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"ToSingleDigitsTable", "[", 
        RowBox[{
        "\"\<Tested\>\"", ",", "res", ",", " ", "tab", ",", " ", "opts"}], 
        "]"}]}]}], "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"MixedAdditionTable", "::", "two"}], "=", " ", 
     "\"\<Mixed addtion of `1` number ?\>\""}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"MixedAdditionTable", "::", "lss"}], " ", "=", " ", 
     "\"\<Numbers all in [-9, 9]: routine is overly complex\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MixedAdditionTable", "[", 
     RowBox[{"n__Integer", ",", " ", "opts___Rule"}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"MixedAdditionTable", "[", 
     RowBox[{
      RowBox[{"{", "n", "}"}], ",", " ", "opts"}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MixedAdditionTable", "[", 
     RowBox[{
      RowBox[{"{", "n__Integer", "}"}], ",", " ", "opts___Rule"}], "]"}], " ",
     ":=", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "lis", ",", " ", "m", ",", "  ", "nd", ",", " ", "max", ",", " ", 
        "line", ",", "  ", "res", ",", "  ", "tab", ",", "  ", "outcome", ",",
         "  ", "sign", ",", " ", "t", ",", " ", "signs"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"lis", " ", "=", " ", 
        RowBox[{"{", "n", "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"m", " ", "=", " ", 
        RowBox[{"Length", "[", "lis", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"m", " ", "<", " ", "2"}], ",", " ", 
         RowBox[{
          RowBox[{"Message", "[", 
           RowBox[{
            RowBox[{"MixedAdditionTable", "::", "two"}], ",", " ", "m"}], 
           "]"}], ";", " ", 
          RowBox[{"Return", "[", 
           RowBox[{"{", "n", "}"}], "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"And", " ", "@@", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"-", "10"}], " ", "<", " ", "#", " ", "<", " ", "10"}], 
             " ", "&"}], "  ", "/@", "  ", "lis"}], ")"}]}], ",", " ", 
         RowBox[{"Message", "[", 
          RowBox[{"MixedAdditionTable", "::", "lss"}], "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"outcome", " ", "=", " ", 
        RowBox[{"Total", "[", "lis", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"sign", "=", " ", 
        RowBox[{"Sign", "[", "outcome", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"max", " ", "=", " ", 
        RowBox[{"Max", "[", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"Abs", "[", "lis", "]"}], ",", " ", 
           RowBox[{"Abs", "[", "outcome", "]"}]}], "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", 
        RowBox[{"maximal", " ", "number", " ", "involved"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"max", " ", "=", " ", 
        RowBox[{"Length", "[", 
         RowBox[{"IntegerDigits", "[", "max", "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"nd", "=", " ", 
        RowBox[{"IntegerDigits", " ", "/@", " ", "lis"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"signs", " ", "=", " ", 
        RowBox[{"Sign", " ", "/@", " ", "lis"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"outcome", " ", "=", " ", 
          RowBox[{"IntegerDigits", "[", "outcome", "]"}]}], ";", "   ", 
         RowBox[{"no", " ", "longer", " ", 
          RowBox[{"used", ":", " ", "res"}]}]}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"tab", "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"t", " ", "=", " ", "#"}], ";", " ", 
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Length", "[", "t", "]"}], " ", "=!=", " ", "max"}], 
              ",", " ", 
              RowBox[{"PrependTo", "[", 
               RowBox[{"t", ",", " ", "0"}], "]"}]}], "]"}], ";", "t"}], 
           ")"}], "&"}], " ", "/@", " ", "nd"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tab", " ", "=", " ", 
        RowBox[{"tab", " ", "signs"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"Total", " ", "/@", " ", 
         RowBox[{"Transpose", "[", "tab", "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"line", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{"\"\<+\>\"", ",", " ", 
          RowBox[{"{", 
           RowBox[{"i", ",", " ", "max"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"tab", ",", " ", "line"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"tab", ",", " ", "res"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"ToSingleDigitsTable", "[", 
        RowBox[{
        "\"\<Tested\>\"", ",", "res", ",", " ", "tab", ",", " ", "opts"}], 
        "]"}]}]}], "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "ToSingleDigitsTable", "]"}], " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{"Differences", " ", "\[Rule]", " ", "True"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ToSingleDigitsTable", "[", 
     RowBox[{"lis_List", ",", "  ", "opts___Rule"}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "outcome", ",", " ", "max", ",", " ", "res", ",", " ", "t", ",", " ", 
        "nd"}], "}"}], ",", " ", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"outcome", " ", "=", " ", 
        RowBox[{"ToSingleDigits", "[", "lis", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"nd", " ", "=", " ", 
        RowBox[{"IntegerDigits", "[", "outcome", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"max", " ", "=", " ", 
        RowBox[{"Length", "[", "nd", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"t", " ", "=", " ", "#"}], ";", " ", 
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Length", "[", "t", "]"}], " ", "<", " ", "max"}], ",",
               " ", 
              RowBox[{"PrependTo", "[", 
               RowBox[{"t", ",", " ", "0"}], "]"}]}], "]"}], ";", " ", "t"}], 
           ")"}], "&"}], " ", "[", "lis", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"ToSingleDigitsTable", "[", 
        RowBox[{"\"\<Tested\>\"", ",", " ", "res", ",", " ", 
         RowBox[{"{", "res", "}"}], ",", " ", "opts"}], "]"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ToSingleDigitsTable", "[", 
     RowBox[{
     "\"\<Tested\>\"", ",", " ", "lis_List", ",", " ", "tablis_List", ",", 
      " ", "opts___Rule"}], "]"}], " ", ":=", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "pos", ",", " ", "rhs", ",", " ", "func", ",", " ", "digits", ",", " ",
         "elem", ",", " ", "lineplus", ",", " ", "change", ",", " ", "k", ",",
         " ", "res", ",", " ", "tab", ",", " ", "difq", ",", " ", "max", " ", 
        ",", " ", "sign", ",", " ", "outcome"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"difq", " ", "=", " ", 
        RowBox[{
         RowBox[{"Differences", " ", "/.", " ", 
          RowBox[{"{", "opts", "}"}]}], " ", "/.", "  ", 
         RowBox[{"Options", "[", "ToSingleDigitsTable", "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"max", " ", "=", " ", 
        RowBox[{"Length", "[", "lis", "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"when", " ", "tested", " ", "then", " ", "max"}], " ", "=", 
         " ", 
         RowBox[{"Length", "[", "lis", "]"}]}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"outcome", " ", "=", " ", 
        RowBox[{"ToSingleDigits", "[", "lis", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"sign", " ", "=", " ", 
        RowBox[{"Sign", "[", "outcome", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"lineplus", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{"\"\<+\>\"", ",", " ", 
          RowBox[{"{", 
           RowBox[{"i", ",", " ", "max"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"digits", " ", "=", " ", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", " ", "9"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"pos", " ", "=", " ", "max"}], ";", "\[IndentingNewLine]", 
       RowBox[{"rhs", " ", "=", " ", 
        RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", "lis"}], ";", "\[IndentingNewLine]", 
       RowBox[{"tab", " ", "=", " ", "tablis"}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Return", "[", 
          RowBox[{"{", 
           RowBox[{
           "res", ",", " ", "tab", ",", " ", "outcome", ",", " ", "sign", ",",
             " ", "max"}], "}"}], "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Switch", "[", 
        RowBox[{
        "sign", " ", ",", " ", "0", ",", " ", "\"\<nothing\>\"", ",", " ", 
         "1", ",", " ", 
         RowBox[{"func", " ", "=", " ", "Floor"}], ",", " ", 
         RowBox[{"-", "1"}], ",", " ", 
         RowBox[{
          RowBox[{"func", " ", "=", " ", "Ceiling"}], ";", " ", 
          RowBox[{"digits", " ", "=", " ", 
           RowBox[{"-", "digits"}]}]}]}], "]"}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"pos", " ", "\[NotEqual]", " ", "0"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"elem", " ", "=", " ", 
           RowBox[{"res", "[", 
            RowBox[{"[", "pos", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"!", 
             RowBox[{"MemberQ", "[", 
              RowBox[{"digits", ",", " ", "elem"}], "]"}]}], ",", " ", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"k", " ", "=", "  ", 
              RowBox[{"func", "[", 
               RowBox[{"elem", "/", "10"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"change", " ", "=", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"k", ",", " ", 
                 RowBox[{
                  RowBox[{"-", "10"}], "  ", "k"}]}], "}"}], " ", "~", "Join",
                "~", " ", "rhs"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"While", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Length", "[", "change", "]"}], " ", "=!=", " ", 
                "max"}], ",", " ", 
               RowBox[{"PrependTo", "[", 
                RowBox[{"change", ",", " ", "0"}], "]"}]}], "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"res", " ", "=", " ", 
              RowBox[{"res", " ", "+", "  ", "change"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"difq", " ", "===", " ", "True"}], ",", " ", 
               RowBox[{"AppendTo", "[", 
                RowBox[{"tab", ",", " ", 
                 RowBox[{"change", " ", "/.", " ", 
                  RowBox[{"0", " ", "\[Rule]", " ", "\"\<\>\""}]}]}], "]"}], 
               ",", " ", 
               RowBox[{"AppendTo", "[", 
                RowBox[{"tab", ",", " ", "res"}], "]"}]}], "]"}]}]}], 
           "\[IndentingNewLine]", "]"}], ";", " ", 
          RowBox[{"(*", "endif", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"pos", " ", "=", " ", 
           RowBox[{"pos", " ", "-", " ", "1"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"rhs", ",", " ", "0"}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "  ", 
       RowBox[{"(*", "endwhile", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"difq", " ", "===", " ", "True"}], ",", " ", 
         RowBox[{
          RowBox[{"AppendTo", "[", 
           RowBox[{"tab", ",", " ", "lineplus"}], "]"}], ";", " ", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"tab", ",", " ", "res"}], "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"TableForm", "[", 
        RowBox[{"tab", ",", " ", 
         RowBox[{"TableAlignments", " ", "\[Rule]", " ", "Right"}], ",", " ", 
         RowBox[{"TableHeadings", " ", "\[Rule]", " ", 
          RowBox[{"{", 
           RowBox[{"Automatic", ",", " ", 
            RowBox[{"Reverse", "[", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"\"\<10\>\"", "^", 
                RowBox[{"ToString", "[", "i", "]"}]}], ",", " ", 
               RowBox[{"{", 
                RowBox[{"i", ",", " ", "0", ",", " ", 
                 RowBox[{"max", "-", "1"}]}], "}"}]}], "]"}], "]"}]}], 
           "}"}]}]}], "]"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"End", "[", "]"}], ";"}], "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EndPackage", "[", "]"}], ";"}]}]}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"e72faa7e-a474-4c15-b174-e35193a67e2b"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". ",
 "Introduction"
}], "Section",ExpressionUUID->"afb71b9a-4fe3-41bc-95a2-c0fad96dad06"],

Cell["\<\
There is a more efficient way for tables of addition and subtraction, see \
Colignatus (2014) and (2015b), that takes better advantage of the place value \
system (decimal system). This would suit the Common Core State Standards \
(CCSS) (2018) objectives.\
\>", "Text",ExpressionUUID->"190fee63-4808-43b2-87f1-2f662ead2769"],

Cell[TextData[{
 "The method is already used in Holland for ",
 StyleBox["addition ",
  FontSlant->"Italic"],
 "in ",
 StyleBox["levels ",
  FontSlant->"Italic"],
 "but this notebook extends for (i)  addition in ",
 StyleBox["differences ",
  FontSlant->"Italic"],
 "and (ii) ",
 StyleBox["subtraction",
  FontSlant->"Italic"],
 " in levels and differences. "
}], "Text",ExpressionUUID->"e9b8de4b-9f1b-4d03-a053-d6a361c57376"],

Cell["\<\
The method is only intended for an intermediate stage in teaching before \
addition and subtraction are mentally fully automated. For example, the \
addition table with differences would be a first encounter, then the table \
with levels would already rely on more work in memory, and then we would \
proceed with automated memory of underflow or overflow.\
\>", "Text",ExpressionUUID->"563ef84c-1bf5-478d-86fa-ffa8faf3b54c"],

Cell["\<\
The method is now available in a package, and the method and routines are \
discussed here. Obviously pupils in elementary school must master the method \
by hand, but the package allows for examples and checking.\
\>", "Text",ExpressionUUID->"39b6e25f-f0cf-44bb-8865-560679c1645a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". ",
 "Discussion"
}], "Section",ExpressionUUID->"45cc9238-2ce2-49f0-a845-253393dd887a"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Main advantages"
}], "Subsection",ExpressionUUID->"838b2551-294e-409d-94b0-7ef1a04f3c6a"],

Cell["\<\
To teach the place value system, it is advisable to add or subtract per \
position.\
\>", "Text",ExpressionUUID->"84764276-6bdf-4714-86e8-e8db818c6a98"],

Cell[CellGroupData[{

Cell["This does not change the original sum.", "Item",ExpressionUUID->"0179f9df-e6aa-4ad3-b76f-a99f77d099a5"],

Cell["\<\
The workflow is into a single direction, not jumping around to the beginning \
and back.\
\>", "Item",ExpressionUUID->"cef8fe4f-9880-46fb-8c75-214fdaca64f9"],

Cell["\<\
Allowing positions to have values outside the [0 , 9] range focuses attention \
upon the place value.\
\>", "Item",ExpressionUUID->"9b1779ae-1fa7-4b4b-9549-b752935199f1"],

Cell["\<\
There is a unity of approach to both addition and subtraction.\
\>", "Item",ExpressionUUID->"bdaa25f0-b06a-4c64-be78-0890f9b9811b"]
}, Open  ]],

Cell["\<\
I have not seen this method elsewhere, except for addition in levels, so if \
you start using this, please refer to this present source, so that others can \
find the proper documentation. See the comparison with existing methods below \
(Section 8).\
\>", "Text",ExpressionUUID->"c132a97c-ab2b-4054-a66f-7c547f2ce162"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Place value system"
}], "Subsection",ExpressionUUID->"44e457a3-0e25-4906-a7c6-1b15e0ca3c7f"],

Cell["\<\
The place value system tends to display with single digits. Adding or \
subtracting may come along with underflow and overflow.\
\>", "Text",ExpressionUUID->"79210a19-4f89-4de6-bb4a-a80dca020421"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToSingleDigits", "[", 
  RowBox[{"{", 
   RowBox[{"11", ",", " ", "9", ",", " ", "14"}], "}"}], "]"}]], "Input",Expre\
ssionUUID->"ed4357f3-f103-4026-8208-079a8ec714d8"],

Cell[BoxData[
 FormBox["1204", TraditionalForm]], "Output",ExpressionUUID->"1dce4bfc-39df-4ce7-9447-591734e05683"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToSingleDigitsTable", "[", 
  RowBox[{"{", 
   RowBox[{"11", ",", " ", "9", ",", " ", "14"}], "}"}], "]"}]], "Input",Expre\
ssionUUID->"23b97f51-6785-462a-9b39-d1185649752c"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"3\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"2\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"1\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"0\"\>"],
        HoldForm]},
      {"1", "0", "11", "9", "14"},
      {"2", "\<\"\"\>", "\<\"\"\>", "1", 
       RowBox[{"-", "10"}]},
      {"3", "\<\"\"\>", "1", 
       RowBox[{"-", "10"}], "\<\"\"\>"},
      {"4", "1", 
       RowBox[{"-", "10"}], "\<\"\"\>", "\<\"\"\>"},
      {"5", "\<\"+\"\>", "\<\"+\"\>", "\<\"+\"\>", "\<\"+\"\>"},
      {"6", "1", "2", "0", "4"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableAlignments -> Right, 
     TableHeadings -> {
      Automatic, {"10"^"3", "10"^"2", "10"^"1", "10"^"0"}}]]], 
  TraditionalForm]], "Output",ExpressionUUID->"c356cd79-fcac-4a4f-b892-\
4c2952d7e3a1"]
}, Open  ]],

Cell["\<\
Colignatus (2014) mentions the possible use of enclosing circles, or colours, \
or brackets for overflow or underflow positions, with numbers like 9 [11]7 = \
1017 = [11][ -9 ]7.\
\>", "Text",ExpressionUUID->"7ec6f833-9ead-4efd-9b70-b0fafbb07c8a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"places", " ", "=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"9", ",", " ", "11", ",", " ", "7"}], "}"}], "  ", "-", " ", 
   RowBox[{"{", 
    RowBox[{"11", ",", " ", 
     RowBox[{"-", "9"}], ",", " ", "7"}], "}"}], " "}]}]], "Input",ExpressionU\
UID->"aa059220-c485-45e1-baaf-2f69ff80356e"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "2"}], ",", "20", ",", "0"}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"187913e5-5d6f-461a-aecc-\
62f9b4222ef4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"places", " ", ".", " ", 
  RowBox[{"{", 
   RowBox[{"100", ",", " ", "10", ",", " ", "1"}], "}"}]}]], "Input",Expressio\
nUUID->"ae8755ed-25e8-4a89-b328-504916b5098b"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",ExpressionUUID->"968b34d5-8db4-421d-a2be-5c61a5fd7c1e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". US Common Core State Standards"
}], "Subsection",ExpressionUUID->"30be3da7-e3ec-4261-8977-2374a3479793"],

Cell["\<\
The method fits within the US Common Core State Standards (2018) when we tell \
kids that a term or line {1, -10} represents the subtraction 1 \[Times] 10 - \
10 \[Times] 1 = 0. It would be more fundamental to adapt the curriculum for \
negative numbers though. The latter is discussed by Colignatus (2018) and \
summarised in Section 8 below.\
\>", "Text",ExpressionUUID->"c6f25e63-b09a-4fce-b9d1-db1f688b8110"],

Cell["\<\
Wikipedia is a portal and no source, and compare: \
https://en.wikipedia.org/wiki/Subtraction#Subtraction_by_hand\
\>", "Text",ExpressionUUID->"69876556-24d4-4a1e-bc4d-4462ca685ca6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". ",
 "With steps of differences"
}], "Section",ExpressionUUID->"1e6454b0-512d-4327-b831-bade222e281f"],

Cell["\<\
These tables use differences, which can be seen from the diagonal form.\
\>", "Text",ExpressionUUID->"904abfcb-cbed-4ee9-9b65-eae1a1bb1a31"],

Cell["\<\
The method of differences is to be preferred as a first phase, because it has \
less steps and shows them all.\
\>", "Text",ExpressionUUID->"78fad10e-f392-426c-9b47-34403f38d568"],

Cell["\<\
Line 5 contains {1, -10} with a negative number, but we might tell kids that \
it is a subtraction, namely 1 \[Times] 10 - 10 \[Times] 1 = 0.\
\>", "Text",ExpressionUUID->"02764c54-de18-4b21-9359-64b139632322"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AdditionTable", "[", 
  RowBox[{"99", ",", " ", "21"}], "]"}]], "Input",ExpressionUUID->"91878eff-\
e5f4-4aee-a65b-a11f2ea824b3"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"2\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"1\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"0\"\>"],
        HoldForm]},
      {"1", "0", "9", "9"},
      {"2", "0", "2", "1"},
      {"3", "\<\"+\"\>", "\<\"+\"\>", "\<\"+\"\>"},
      {"4", "0", "11", "10"},
      {"5", "\<\"\"\>", "1", 
       RowBox[{"-", "10"}]},
      {"6", "1", 
       RowBox[{"-", "10"}], "\<\"\"\>"},
      {"7", "\<\"+\"\>", "\<\"+\"\>", "\<\"+\"\>"},
      {"8", "1", "2", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableAlignments -> Right, 
     TableHeadings -> {Automatic, {"10"^"2", "10"^"1", "10"^"0"}}]]], 
  TraditionalForm]], "Output",ExpressionUUID->"b39fc6ec-f044-4cf1-bfad-\
724ec900e4ae"]
}, Open  ]],

Cell["\<\
Training on addition will eventually cause a different workflow, when \
addition becomes mentally fully automated. A higher level script for 99 + 21 \
would be: 9 + 1 = 10, write 0 and remember 1, 1 + 9 + 2 = 12, write 2 and \
remember 1, write 1, and check and finish. The addition table in levels (next \
Section) would be an intermediate phase between using differences here and \
the compact workflow with automation.\
\>", "Text",ExpressionUUID->"b073486a-ff71-4c6c-b49d-09bfcbb74787"],

Cell["Practice makes perfect. More tables or bigger numbers.", "Text",ExpressionUUID->"b4179950-d67a-439d-87c3-0408a0777bee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AdditionTable", "[", 
  RowBox[{"999", ",", " ", "777", ",", " ", "123"}], "]"}]], "Input",Expressio\
nUUID->"a5b6c659-0f4f-41f5-a08b-9e437f028ea8"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"3\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"2\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"1\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"0\"\>"],
        HoldForm]},
      {"1", "0", "9", "9", "9"},
      {"2", "0", "7", "7", "7"},
      {"3", "0", "1", "2", "3"},
      {"4", "\<\"+\"\>", "\<\"+\"\>", "\<\"+\"\>", "\<\"+\"\>"},
      {"5", "0", "17", "18", "19"},
      {"6", "\<\"\"\>", "\<\"\"\>", "1", 
       RowBox[{"-", "10"}]},
      {"7", "\<\"\"\>", "1", 
       RowBox[{"-", "10"}], "\<\"\"\>"},
      {"8", "1", 
       RowBox[{"-", "10"}], "\<\"\"\>", "\<\"\"\>"},
      {"9", "\<\"+\"\>", "\<\"+\"\>", "\<\"+\"\>", "\<\"+\"\>"},
      {"10", "1", "8", "9", "9"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableAlignments -> Right, 
     TableHeadings -> {
      Automatic, {"10"^"3", "10"^"2", "10"^"1", "10"^"0"}}]]], 
  TraditionalForm]], "Output",ExpressionUUID->"984872d3-3ad8-4119-8d99-\
3b41ca8a76d7"]
}, Open  ]],

Cell["\<\
Line 5 below contains {-1, 10, 0} with a negative number, but it we might \
tell kids that it is subtraction: - 1 \[Times] 100 + 10 \[Times] 10 + 0 \
\[Times] 1 = 0.\
\>", "Text",ExpressionUUID->"68f5a330-6194-44bc-92e1-8ca512a7a31b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SubtractionTable", "[", 
  RowBox[{"491", ",", " ", "753"}], "]"}]], "Input",ExpressionUUID->"bd6ed29a-\
1975-4846-a466-112be3ab5ec9"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "SubtractionTable","ord",
    "\"Order switched into \\!\\(\\*FormBox[\\\"753\\\", TraditionalForm]\\) \
- \\!\\(\\*FormBox[\\\"491\\\", TraditionalForm]\\)\"",2,79,17,
    32532858265426121747,"Local","Cool`MathEd`AdditionTable`SubtractionTable"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"a0f77b4d-1a1c-419d-8b6e-fd9e2f91c508"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"2\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"1\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"0\"\>"],
        HoldForm]},
      {"1", "7", "5", "3"},
      {"2", "4", "9", "1"},
      {"3", "\<\"-\"\>", "\<\"-\"\>", "\<\"-\"\>"},
      {"4", "3", 
       RowBox[{"-", "4"}], "2"},
      {"5", 
       RowBox[{"-", "1"}], "10", "\<\"\"\>"},
      {"6", "\<\"+\"\>", "\<\"+\"\>", "\<\"+\"\>"},
      {"7", "2", "6", "2"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableAlignments -> Right, 
     TableHeadings -> {Automatic, {"10"^"2", "10"^"1", "10"^"0"}}]]], 
  TraditionalForm]], "Output",ExpressionUUID->"3c963dca-2be3-452f-9e84-\
0f1e14d15eb9"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". ",
 "With steps in levels"
}], "Section",ExpressionUUID->"ddcec3bc-74aa-425b-bc30-e588be5aefec"],

Cell["\<\
That these tables use levels can be seen from the repeat of the place values.\
\>", "Text",ExpressionUUID->"01089270-0d80-423c-b377-83d6e681b832"],

Cell["\<\
For addition, in these levels, this method actually has been used widely in \
Holland. It however hides the subtraction, and it hasn\[CloseCurlyQuote]t \
been developed further for a table for subtraction. This may suggest to kids \
that subtraction must be handled differently, while there is little need for \
that.\
\>", "Text",ExpressionUUID->"77e46a05-e83c-45cc-a58c-1b36a1e1ab0e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AdditionTable", "[", 
  RowBox[{"99", ",", " ", "21", ",", " ", 
   RowBox[{"Differences", " ", "\[Rule]", " ", "False"}]}], "]"}]], "Input",Ex\
pressionUUID->"61f4be85-67a1-4ca6-8720-697b9a786202"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"2\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"1\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"0\"\>"],
        HoldForm]},
      {"1", "0", "9", "9"},
      {"2", "0", "2", "1"},
      {"3", "\<\"+\"\>", "\<\"+\"\>", "\<\"+\"\>"},
      {"4", "0", "11", "10"},
      {"5", "0", "12", "0"},
      {"6", "1", "2", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableAlignments -> Right, 
     TableHeadings -> {Automatic, {"10"^"2", "10"^"1", "10"^"0"}}]]], 
  TraditionalForm]], "Output",ExpressionUUID->"ca307bf2-9bc7-425c-8c1c-\
5d3c1829f532"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AdditionTable", "[", 
  RowBox[{"999", ",", " ", "777", ",", " ", "123", ",", " ", 
   RowBox[{"Differences", " ", "\[Rule]", " ", "False"}]}], "]"}]], "Input",Ex\
pressionUUID->"14c33dc2-bbc4-48c5-9c62-b7507291f523"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"3\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"2\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"1\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"0\"\>"],
        HoldForm]},
      {"1", "0", "9", "9", "9"},
      {"2", "0", "7", "7", "7"},
      {"3", "0", "1", "2", "3"},
      {"4", "\<\"+\"\>", "\<\"+\"\>", "\<\"+\"\>", "\<\"+\"\>"},
      {"5", "0", "17", "18", "19"},
      {"6", "0", "17", "19", "9"},
      {"7", "0", "18", "9", "9"},
      {"8", "1", "8", "9", "9"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableAlignments -> Right, 
     TableHeadings -> {
      Automatic, {"10"^"3", "10"^"2", "10"^"1", "10"^"0"}}]]], 
  TraditionalForm]], "Output",ExpressionUUID->"52ca3859-4319-4c1b-8613-\
3f5a0c1af8b4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SubtractionTable", "[", 
  RowBox[{"753", ",", " ", "491", ",", " ", 
   RowBox[{"Differences", " ", "\[Rule]", " ", "False"}]}], "]"}]], "Input",Ex\
pressionUUID->"f0774834-0677-4d2e-9bc5-79945126653b"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"2\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"1\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"0\"\>"],
        HoldForm]},
      {"1", "7", "5", "3"},
      {"2", "4", "9", "1"},
      {"3", "\<\"-\"\>", "\<\"-\"\>", "\<\"-\"\>"},
      {"4", "3", 
       RowBox[{"-", "4"}], "2"},
      {"5", "2", "6", "2"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableAlignments -> Right, 
     TableHeadings -> {Automatic, {"10"^"2", "10"^"1", "10"^"0"}}]]], 
  TraditionalForm]], "Output",ExpressionUUID->"09331434-2eed-4c07-882b-\
8a0750b10478"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". ",
 "Calculation strategy"
}], "Section",ExpressionUUID->"b8d4db93-5dc9-4cdf-9b8a-23a66988bb03"],

Cell["Pupils must also develop some calculation strategies:", "Text",ExpressionUUID->"167c239c-58c7-4387-9c6f-35ffaee71eb6"],

Cell[CellGroupData[{

Cell["\<\
Addition allows that more numbers are added at the same time, and the order \
doesn\[CloseCurlyQuote]t matter.\
\>", "Item",ExpressionUUID->"1d938329-0bda-48d5-8061-52e37522aa8a"],

Cell["\<\
Simple subtraction has only two numbers, the largest minus the smallest. If \
one really wants to subtract a large number from a smaller one, change the \
order and multiply the outcome by -1. If there are more numbers to subtract, \
first add all numbers that must be subtracted. \
\>", "Item",ExpressionUUID->"14ed5d23-8bb8-4df9-819d-c23f734ff7c9"],

Cell["\<\
Involved subtraction uses more than two numbers: see the next section. In \
such case, there can be a negative outcome. One must be aware that a number \
like -123 will be displayed as {-1, -2, -3}.\
\>", "Item",ExpressionUUID->"a3bf8940-2ca8-4d3e-b004-e9c824fb0af0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". Subtraction in given order or with more numbers"
}], "Section",ExpressionUUID->"0fada0b1-808b-4dda-863a-d5da4718fa61"],

Cell["\<\
Here we must make a rough judgement whether the outcome will be positive or \
negative. Depending upon this judgement we add or subtract 10 in the various \
places.\
\>", "Text",ExpressionUUID->"a3bff7f2-6310-4090-9d42-43027e89051e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SubtractionTable", "[", 
  RowBox[{"{", 
   RowBox[{"18", ",", " ", "30", ",", " ", "5"}], "}"}], "]"}]], "Input",Expre\
ssionUUID->"b09bae3e-429e-4e3a-86a0-1ee77b3f5dbe"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"1\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"0\"\>"],
        HoldForm]},
      {"1", "1", "8"},
      {"2", "3", "0"},
      {"3", "0", "5"},
      {"4", "\<\"-\"\>", "\<\"-\"\>"},
      {"5", 
       RowBox[{"-", "2"}], "3"},
      {"6", "1", 
       RowBox[{"-", "10"}]},
      {"7", "\<\"+\"\>", "\<\"+\"\>"},
      {"8", 
       RowBox[{"-", "1"}], 
       RowBox[{"-", "7"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableAlignments -> Right, 
     TableHeadings -> {Automatic, {"10"^"1", "10"^"0"}}]]], 
  TraditionalForm]], "Output",ExpressionUUID->"cb9e2a40-6111-48ae-afdd-\
d209e962234d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SubtractionTable", "[", 
  RowBox[{"{", 
   RowBox[{"11", ",", " ", "99"}], "}"}], "]"}]], "Input",ExpressionUUID->\
"bed72455-3ec1-4884-82aa-3f3767c70245"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"1\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"0\"\>"],
        HoldForm]},
      {"1", "1", "1"},
      {"2", "9", "9"},
      {"3", "\<\"-\"\>", "\<\"-\"\>"},
      {"4", 
       RowBox[{"-", "8"}], 
       RowBox[{"-", "8"}]},
      {"5", "\<\"+\"\>", "\<\"+\"\>"},
      {"6", 
       RowBox[{"-", "8"}], 
       RowBox[{"-", "8"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableAlignments -> Right, 
     TableHeadings -> {Automatic, {"10"^"1", "10"^"0"}}]]], 
  TraditionalForm]], "Output",ExpressionUUID->"c8e8112f-22f0-4e0a-b7f2-\
376a79b44be1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SubtractionTable", "[", 
  RowBox[{"11", ",", " ", "99", ",", " ", "78"}], "]"}]], "Input",ExpressionUU\
ID->"e2a4c71f-a630-4b9d-8de7-b3cab5f13431"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"2\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"1\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"0\"\>"],
        HoldForm]},
      {"1", "0", "1", "1"},
      {"2", "0", "9", "9"},
      {"3", "0", "7", "8"},
      {"4", "\<\"-\"\>", "\<\"-\"\>", "\<\"-\"\>"},
      {"5", "0", 
       RowBox[{"-", "15"}], 
       RowBox[{"-", "16"}]},
      {"6", "\<\"\"\>", 
       RowBox[{"-", "1"}], "10"},
      {"7", 
       RowBox[{"-", "1"}], "10", "\<\"\"\>"},
      {"8", "\<\"+\"\>", "\<\"+\"\>", "\<\"+\"\>"},
      {"9", 
       RowBox[{"-", "1"}], 
       RowBox[{"-", "6"}], 
       RowBox[{"-", "6"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableAlignments -> Right, 
     TableHeadings -> {Automatic, {"10"^"2", "10"^"1", "10"^"0"}}]]], 
  TraditionalForm]], "Output",ExpressionUUID->"e9115a16-f7bc-4f7b-aacd-\
9e6df4b4ebde"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SubtractionTable", "[", 
  RowBox[{"999", ",", " ", "11", ",", " ", "99", ",", " ", "78"}], 
  "]"}]], "Input",ExpressionUUID->"61c6c51a-5b59-4d8e-9880-62ee78504171"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"2\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"1\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"0\"\>"],
        HoldForm]},
      {"1", "9", "9", "9"},
      {"2", "0", "1", "1"},
      {"3", "0", "9", "9"},
      {"4", "0", "7", "8"},
      {"5", "\<\"-\"\>", "\<\"-\"\>", "\<\"-\"\>"},
      {"6", "9", 
       RowBox[{"-", "8"}], 
       RowBox[{"-", "9"}]},
      {"7", "\<\"\"\>", 
       RowBox[{"-", "1"}], "10"},
      {"8", 
       RowBox[{"-", "1"}], "10", "\<\"\"\>"},
      {"9", "\<\"+\"\>", "\<\"+\"\>", "\<\"+\"\>"},
      {"10", "8", "1", "1"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableAlignments -> Right, 
     TableHeadings -> {Automatic, {"10"^"2", "10"^"1", "10"^"0"}}]]], 
  TraditionalForm]], "Output",ExpressionUUID->"5c4461be-04dd-4b89-a9c0-\
8711d6fd3f82"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". ",
 "When the routines are overly complex"
}], "Section",ExpressionUUID->"b0d2a19b-a80e-4e8d-b66c-3bbb56831cd4"],

Cell["\<\
When we add or subtract single digit numbers, then the routines are overly \
complex, since there is no real need for more columns. The routines now give \
a warning on this. The routines still show the general algorithm, for this \
might have some didactic value.\
\>", "Text",ExpressionUUID->"74bc7233-136c-4d78-bb8b-926119cbc629"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AdditionTable", "[", 
  RowBox[{"8", ",", " ", "3", ",", " ", "6"}], "]"}]], "Input",ExpressionUUID-\
>"7cd7361a-cdc9-4557-b5da-4cd45789e2e9"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "AdditionTable","lss",
    "\"Numbers all less than 10: routine is overly complex\"",2,43,15,
    32532858265426121747,"Local","Cool`MathEd`AdditionTable`AdditionTable"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"79cddb8b-34a6-4eb6-a308-60f8c760ced5"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"1\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"0\"\>"],
        HoldForm]},
      {"1", "0", "8"},
      {"2", "0", "3"},
      {"3", "0", "6"},
      {"4", "\<\"+\"\>", "\<\"+\"\>"},
      {"5", "0", "17"},
      {"6", "1", 
       RowBox[{"-", "10"}]},
      {"7", "\<\"+\"\>", "\<\"+\"\>"},
      {"8", "1", "7"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableAlignments -> Right, 
     TableHeadings -> {Automatic, {"10"^"1", "10"^"0"}}]]], 
  TraditionalForm]], "Output",ExpressionUUID->"122b6bbe-cac1-4e78-9fac-\
22e7177f24ac"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SubtractionTable", "[", 
  RowBox[{"8", ",", " ", "3", ",", " ", "6", ",", " ", "9"}], "]"}]], "Input",\
ExpressionUUID->"74057ed2-5a72-4445-95b9-8c26e8896290"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "SubtractionTable","lss",
    "\"Numbers all less than 10: routine is overly complex\"",2,44,16,
    32532858265426121747,"Local","Cool`MathEd`AdditionTable`SubtractionTable"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"4c1b3e74-5003-4872-bd13-fc9112c6f2af"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"1\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"0\"\>"],
        HoldForm]},
      {"1", "0", "8"},
      {"2", "0", "3"},
      {"3", "0", "6"},
      {"4", "0", "9"},
      {"5", "\<\"-\"\>", "\<\"-\"\>"},
      {"6", "0", 
       RowBox[{"-", "10"}]},
      {"7", 
       RowBox[{"-", "1"}], "10"},
      {"8", "\<\"+\"\>", "\<\"+\"\>"},
      {"9", 
       RowBox[{"-", "1"}], "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableAlignments -> Right, 
     TableHeadings -> {Automatic, {"10"^"1", "10"^"0"}}]]], 
  TraditionalForm]], "Output",ExpressionUUID->"a4a82cde-0e1f-416a-8fd3-\
15e41fafebbb"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". ",
 "Comparison with Common Core and existing methods"
}], "Section",ExpressionUUID->"0f19e7d6-cc1b-4204-b07a-73e55a01788d"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Position in the US Common Core"
}], "Subsection",ExpressionUUID->"f1f69fdf-2f3c-4873-9230-4e5b3592dd52"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". It can be used already"
}], "Subsubsection",ExpressionUUID->"4ce7bf8e-4b50-403c-b8fe-c4195e306115"],

Cell["\<\
The US Common Core State Standards (2018) has subtraction from kindergarten. \
The method thus can be used when we tell kids that {1, -10} codifies a \
subtraction, namely 1 \[Times] 10 - 10 \[Times] 1 = 0.\
\>", "Text",ExpressionUUID->"56d10f1d-b058-46f5-9a4c-67854beffa97"],

Cell["\<\
Keep in mind that this method is only intended for an intermediate stage in \
teaching before addition and subtraction are mentally fully automated. \
\>", "Text",ExpressionUUID->"1b142138-6251-4ec5-95aa-7ded2c61de86"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". Option to adapt the curriculum too"
}], "Subsubsection",ExpressionUUID->"85a064f5-9a5c-46ce-a7d1-b0095a306553"],

Cell[TextData[{
 "We rather would want to speak about negative numbers. The method can be \
applied with open use of negative numbers when the order in the curriculum of \
",
 StyleBox["fractions",
  FontSlant->"Italic"],
 " and ",
 StyleBox["negative numbers",
  FontSlant->"Italic"],
 " is interchanged. See Colignatus (2018) for an involved discussion. "
}], "Text",ExpressionUUID->"da834444-5aa4-40fe-b778-b624c8accac2"],

Cell[CellGroupData[{

Cell["\<\
Currently negative numbers are introduced in Grade 6, but they better be \
mastered in Grade 2 and 3. First the whole numbers and later the fractions. \
\>", "Item",ExpressionUUID->"8f3a34c5-4f54-46fa-a8f8-ead02ba0c273"],

Cell["\<\
Grade 2 now works up to 1000 but it would better to have -10 first. \
\>", "Item",ExpressionUUID->"8e6d35c8-7d86-4d52-81f0-b8b195b2699c"],

Cell["\<\
The major objective is to get to understand the place value system and the \
properties of addition and subtraction. Negative numbers appear to be \
relevant for this.\
\>", "Item",ExpressionUUID->"cc2cc15f-1678-4ebf-a0a0-9acf76d3f513"],

Cell["\<\
Now fractions are discussed in Grade 3-5 but they better be discussed in \
Grade 4-6. \
\>", "Item",ExpressionUUID->"24dfa176-7113-4436-ad7f-d64764df37c5"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Use in Holland for addition in levels only"
}], "Subsection",ExpressionUUID->"6e8e2f51-d505-4a0a-b3bf-37e24f507a00"],

Cell[TextData[{
 "There is a widely used application in Holland already, but only for the ",
 StyleBox["addition in levels",
  FontSlant->"Italic"],
 " (Section 4 above). Working in levels obscures the internal subtraction \
that is being done. Thus, the present news is the development of (i) \
differences for addition and (ii) tables for subtraction (either in levels or \
differences). "
}], "Text",ExpressionUUID->"0ad7f4a2-ed36-42e6-87e0-0c1bad238e32"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Methods of partial sums and partial differences"
}], "Subsection",ExpressionUUID->"7f25e13e-16d4-4645-bdc6-6ef0b8ea84f4"],

Cell[TextData[{
 "The proposed method compares a bit to the ",
 StyleBox["partial sums ",
  FontSlant->"Italic"],
 "and ",
 StyleBox["partial differences ",
  FontSlant->"Italic"],
 "methods in \[OpenCurlyDoubleQuote]realistic mathematics education\
\[CloseCurlyDoubleQuote] at the University of Utrecht, also adopted by ",
 StyleBox["Everyday Mathematics ",
  FontSlant->"Italic"],
 "(2018abc) at the University of Chicago. An (here) irrelevant difference is \
that the latter work from left to right instead from right to left. The \
relevant distinction is that the latter create new big numbers, which departs \
from the notion of place value again. There can also be awkward combinations \
of addition and subtraction. Everyday Mathematics (2018c) ends up with the \
input of this sum, and its first three lines, but it obscures the work that \
still has to be done in the second part of the table."
}], "Text",ExpressionUUID->"8662654b-5b05-447f-808f-51936e7c816f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MixedAdditionTable", "[", 
  RowBox[{"500", ",", " ", 
   RowBox[{"-", "40"}], ",", " ", 
   RowBox[{"-", "2"}]}], "]"}]], "Input",ExpressionUUID->"5afcdb3f-e3f6-479d-\
ad34-c7164a435648"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"2\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"1\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"0\"\>"],
        HoldForm]},
      {"1", "5", "0", "0"},
      {"2", "0", 
       RowBox[{"-", "4"}], "0"},
      {"3", "0", "0", 
       RowBox[{"-", "2"}]},
      {"4", "\<\"+\"\>", "\<\"+\"\>", "\<\"+\"\>"},
      {"5", "5", 
       RowBox[{"-", "4"}], 
       RowBox[{"-", "2"}]},
      {"6", "\<\"\"\>", 
       RowBox[{"-", "1"}], "10"},
      {"7", 
       RowBox[{"-", "1"}], "10", "\<\"\"\>"},
      {"8", "\<\"+\"\>", "\<\"+\"\>", "\<\"+\"\>"},
      {"9", "4", "5", "8"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableAlignments -> Right, 
     TableHeadings -> {Automatic, {"10"^"2", "10"^"1", "10"^"0"}}]]], 
  TraditionalForm]], "Output",ExpressionUUID->"b0e82216-2324-4c0c-976c-\
24503bb8891e"]
}, Open  ]],

Cell[TextData[{
 "PM. The ",
 StyleBox["partial differences method",
  FontSlant->"Italic"],
 " also has \"subtraction of numbers\" but this can better be interpreted as \
the implied use of negative numbers. It would be better to have the whole \
number line already available at the end of Grade 3, which repeats above \
argument."
}], "Text",ExpressionUUID->"890eeed1-888e-4b21-9a50-2d1dd67d1090"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". ",
 "Some additional features"
}], "Section",ExpressionUUID->"bf566b93-9dae-4724-8435-96055ed8138f"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Mixed addition table"
}], "Subsection",ExpressionUUID->"c8e33fa7-48c3-4342-bc5e-6b537fd8dd3a"],

Cell["\<\
The following allows a mixture of positive and negative integers. It might \
not be so handy to mix such cases, but perhaps it is useful for exercises. It \
was used above to look at the method of partial differences.\
\>", "Text",ExpressionUUID->"5960ca4e-bc4e-4f1c-b098-28979fcf3988"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MixedAdditionTable", "[", 
  RowBox[{"10", ",", " ", 
   RowBox[{"-", "15"}], ",", " ", 
   RowBox[{"-", "6"}], ",", " ", "23"}], "]"}]], "Input",ExpressionUUID->\
"cc04dde6-ecd0-4f03-a30b-c233c36c73c6"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"1\"\>"],
        HoldForm], 
       TagBox[
        SuperscriptBox["\<\"10\"\>", "\<\"0\"\>"],
        HoldForm]},
      {"1", "1", "0"},
      {"2", 
       RowBox[{"-", "1"}], 
       RowBox[{"-", "5"}]},
      {"3", "0", 
       RowBox[{"-", "6"}]},
      {"4", "2", "3"},
      {"5", "\<\"+\"\>", "\<\"+\"\>"},
      {"6", "2", 
       RowBox[{"-", "8"}]},
      {"7", 
       RowBox[{"-", "1"}], "10"},
      {"8", "\<\"+\"\>", "\<\"+\"\>"},
      {"9", "1", "2"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableAlignments -> Right, 
     TableHeadings -> {Automatic, {"10"^"1", "10"^"0"}}]]], 
  TraditionalForm]], "Output",ExpressionUUID->"5fd4f9bf-e06f-4664-8a44-\
8d29915739b4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". For the step from counting to addition"
}], "Subsection",ExpressionUUID->"abe02bb0-707d-4d42-b0c4-1e1f278d5c68"],

Cell[TextData[{
 "Key didactics is to properly memorise the \[OpenCurlyDoubleQuote]",
 StyleBox["Table of Basic Addition",
  FontSlant->"Italic"],
 "\[CloseCurlyDoubleQuote], since this is the step from counting to addition. \
Pupils who get stuck at counting - still using their fingers - will not have \
memorised this table. Its \[OpenCurlyDoubleQuote]version in sounds\
\[CloseCurlyDoubleQuote] - also before reading and writing - is part of \
memorisation. I thank pedagogue and teacher drs. A.I. Roessingh for these \
insights."
}], "Text",ExpressionUUID->"494019ec-126f-460d-ba42-384c67e75a0b"],

Cell["\<\
PM. (i) The entries of the table better have the orientation of the system of \
co-ordinates. (ii) An element within the table also shows the possible \
additions and subtractions w.r.t. the entries.\
\>", "Text",ExpressionUUID->"35c79d64-88d1-4a9c-bf8d-2dd669a19f19"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableOfBasicAddition", "[", "]"}]], "Input",ExpressionUUID->"ae2b2bb4-2414-499c-9e81-8079374cee48"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["0",
        HoldForm], 
       TagBox["1",
        HoldForm], 
       TagBox["2",
        HoldForm], 
       TagBox["3",
        HoldForm], 
       TagBox["4",
        HoldForm], 
       TagBox["5",
        HoldForm], 
       TagBox["6",
        HoldForm], 
       TagBox["7",
        HoldForm], 
       TagBox["8",
        HoldForm], 
       TagBox["9",
        HoldForm], 
       TagBox["10",
        HoldForm]},
      {
       TagBox["10",
        HoldForm], 
       "10", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
      {
       TagBox["9",
        HoldForm], "9", 
       "10", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
      {
       TagBox["8",
        HoldForm], "8", "9", 
       "10", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
      {
       TagBox["7",
        HoldForm], "7", "8", "9", 
       "10", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>"},
      {
       TagBox["6",
        HoldForm], "6", "7", "8", "9", 
       "10", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>"},
      {
       TagBox["5",
        HoldForm], "5", "6", "7", "8", "9", 
       "10", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
      {
       TagBox["4",
        HoldForm], "4", "5", "6", "7", "8", "9", 
       "10", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
      {
       TagBox["3",
        HoldForm], "3", "4", "5", "6", "7", "8", "9", 
       "10", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
      {
       TagBox["2",
        HoldForm], "2", "3", "4", "5", "6", "7", "8", "9", 
       "10", "\<\"\"\>", "\<\"\"\>"},
      {
       TagBox["1",
        HoldForm], "1", "2", "3", "4", "5", "6", "7", "8", "9", 
       "10", "\<\"\"\>"},
      {
       TagBox["0",
        HoldForm], "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[1.0499999999999998`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{10, 9, 8, 7, 6, 5, 4, 3, 2, 1, 0}, {0, 1, 2, 3, 4, 5, 
      6, 7, 8, 9, 10}}, TableSpacing -> {1, 1.5}]]], 
  TraditionalForm]], "Output",ExpressionUUID->"3e09222a-4b94-42a7-a58e-\
414f614d80f1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". For the step from positive to negative"
}], "Subsection",ExpressionUUID->"c8876381-8740-4cd4-8e67-c54cb2ca3e04"],

Cell["For some negative numbers it looks like this.", "Text",ExpressionUUID->"7df6dae7-036c-433b-93b6-e80c2e976514"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableOfBasicAddition", "[", 
  RowBox[{
   RowBox[{"-", "5"}], ",", " ", "5"}], "]"}]], "Input",ExpressionUUID->\
"6739be70-e7d9-4b65-b0cc-e04e91436bad"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox[
        RowBox[{"-", "5"}],
        HoldForm], 
       TagBox[
        RowBox[{"-", "4"}],
        HoldForm], 
       TagBox[
        RowBox[{"-", "3"}],
        HoldForm], 
       TagBox[
        RowBox[{"-", "2"}],
        HoldForm], 
       TagBox[
        RowBox[{"-", "1"}],
        HoldForm], 
       TagBox["0",
        HoldForm], 
       TagBox["1",
        HoldForm], 
       TagBox["2",
        HoldForm], 
       TagBox["3",
        HoldForm], 
       TagBox["4",
        HoldForm], 
       TagBox["5",
        HoldForm]},
      {
       TagBox["5",
        HoldForm], "0", "1", "2", "3", "4", 
       "5", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
      {
       TagBox["4",
        HoldForm], 
       RowBox[{"-", "1"}], "0", "1", "2", "3", "4", 
       "5", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
      {
       TagBox["3",
        HoldForm], 
       RowBox[{"-", "2"}], 
       RowBox[{"-", "1"}], "0", "1", "2", "3", "4", 
       "5", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
      {
       TagBox["2",
        HoldForm], 
       RowBox[{"-", "3"}], 
       RowBox[{"-", "2"}], 
       RowBox[{"-", "1"}], "0", "1", "2", "3", "4", 
       "5", "\<\"\"\>", "\<\"\"\>"},
      {
       TagBox["1",
        HoldForm], 
       RowBox[{"-", "4"}], 
       RowBox[{"-", "3"}], 
       RowBox[{"-", "2"}], 
       RowBox[{"-", "1"}], "0", "1", "2", "3", "4", "5", "\<\"\"\>"},
      {
       TagBox["0",
        HoldForm], 
       RowBox[{"-", "5"}], 
       RowBox[{"-", "4"}], 
       RowBox[{"-", "3"}], 
       RowBox[{"-", "2"}], 
       RowBox[{"-", "1"}], "0", "1", "2", "3", "4", "5"},
      {
       TagBox[
        RowBox[{"-", "1"}],
        HoldForm], "\<\"\"\>", 
       RowBox[{"-", "5"}], 
       RowBox[{"-", "4"}], 
       RowBox[{"-", "3"}], 
       RowBox[{"-", "2"}], 
       RowBox[{"-", "1"}], "0", "1", "2", "3", "4"},
      {
       TagBox[
        RowBox[{"-", "2"}],
        HoldForm], "\<\"\"\>", "\<\"\"\>", 
       RowBox[{"-", "5"}], 
       RowBox[{"-", "4"}], 
       RowBox[{"-", "3"}], 
       RowBox[{"-", "2"}], 
       RowBox[{"-", "1"}], "0", "1", "2", "3"},
      {
       TagBox[
        RowBox[{"-", "3"}],
        HoldForm], "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
       RowBox[{"-", "5"}], 
       RowBox[{"-", "4"}], 
       RowBox[{"-", "3"}], 
       RowBox[{"-", "2"}], 
       RowBox[{"-", "1"}], "0", "1", "2"},
      {
       TagBox[
        RowBox[{"-", "4"}],
        HoldForm], "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
       RowBox[{"-", "5"}], 
       RowBox[{"-", "4"}], 
       RowBox[{"-", "3"}], 
       RowBox[{"-", "2"}], 
       RowBox[{"-", "1"}], "0", "1"},
      {
       TagBox[
        RowBox[{"-", "5"}],
        HoldForm], "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
       RowBox[{"-", "5"}], 
       RowBox[{"-", "4"}], 
       RowBox[{"-", "3"}], 
       RowBox[{"-", "2"}], 
       RowBox[{"-", "1"}], "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[1.0499999999999998`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{5, 4, 3, 2, 1, 
      0, -1, -2, -3, -4, -5}, {-5, -4, -3, -2, -1, 0, 1, 2, 3, 4, 5}}, 
     TableSpacing -> {1, 1.5}]]], TraditionalForm]], "Output",ExpressionUUID->\
"2fb8c63f-6f35-429d-8f3f-aa997f24567e"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". ",
 "The routines"
}], "Section",ExpressionUUID->"db23e7cc-a8f3-4f19-b9a8-2f9cd6511ff4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Cool`MathEd`AdditionTable`*"}]], "Input",ExpressionUUID->"9648044f-a802-4708-8e09-aa68967a08bf"],

Cell[BoxData[
 DynamicModuleBox[{Typeset`open$$ = True}, 
  PaneSelectorBox[{False->
   RowBox[{
    OpenerBox[Dynamic[Typeset`open$$],
     ImageSize->Small], 
    StyleBox["Cool`MathEd`AdditionTable`", "InfoHeading"]}], True->GridBox[{
     {
      RowBox[{
       OpenerBox[Dynamic[Typeset`open$$],
        ImageSize->Small], 
       StyleBox["Cool`MathEd`AdditionTable`", "InfoHeading"]}]},
     {GridBox[{
        {
         ButtonBox["AdditionTable",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info393734493366-1684409", {
            "AdditionTable", "Cool`MathEd`AdditionTable`"}},
          ButtonNote->"Cool`MathEd`AdditionTable`"], 
         ButtonBox["SubtractionTable",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info393734493366-1684409", {
            "SubtractionTable", "Cool`MathEd`AdditionTable`"}},
          ButtonNote->"Cool`MathEd`AdditionTable`"], 
         ButtonBox["ToSingleDigitsTable",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info393734493366-1684409", {
            "ToSingleDigitsTable", "Cool`MathEd`AdditionTable`"}},
          ButtonNote->"Cool`MathEd`AdditionTable`"]},
        {
         ButtonBox["MixedAdditionTable",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info393734493366-1684409", {
            "MixedAdditionTable", "Cool`MathEd`AdditionTable`"}},
          ButtonNote->"Cool`MathEd`AdditionTable`"], 
         ButtonBox["TableOfBasicAddition",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info393734493366-1684409", {
            "TableOfBasicAddition", "Cool`MathEd`AdditionTable`"}},
          ButtonNote->"Cool`MathEd`AdditionTable`"], ""},
        {
         ButtonBox["SquareTableOfAddition",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info393734493366-1684409", {
            "SquareTableOfAddition", "Cool`MathEd`AdditionTable`"}},
          ButtonNote->"Cool`MathEd`AdditionTable`"], 
         ButtonBox["ToSingleDigits",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info393734493366-1684409", {
            "ToSingleDigits", "Cool`MathEd`AdditionTable`"}},
          ButtonNote->"Cool`MathEd`AdditionTable`"], ""}
       },
       DefaultBaseStyle->"InfoGrid",
       GridBoxItemSize->{"Columns" -> {{
            Scaled[0.31666666666666665`]}}}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}]}, 
   Dynamic[Typeset`open$$],
   ImageSize->Automatic]]], "Print", \
"InfoCell",ExpressionUUID->"43923a7f-f65d-4200-bb2c-beb9f6695313"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "AdditionTable"}]], "Input",ExpressionUUID->"10aa7b44-5d5b-460d-a393-98704ebdcec5"],

Cell[BoxData["\<\"AdditionTable[n__Integer] gives a table that adds the \
integers, that must be positive, using the place value system. The integers \
are added per digit position, and each overflow generates a new line in the \
table\\nAdditionTable[{n__Integer}] is another input format\\nOptions are \
passed on to ToSingleDigitsTable. Default there is Differences -> True \
(default); otherwise levels\\nWhen all integers are in [0, 9] then there is a \
warning that the routine is overly complex for such a case\"\>"], "Print", \
"PrintUsage",
 CellTags->
  "Info403734493366-1684409",ExpressionUUID->"1952c713-b761-4009-b788-\
cba617ff3388"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SubtractionTable"}]], "Input",ExpressionUUID->"34ba3f25-4f23-4ed4-a7b5-b202397c3e6e"],

Cell[BoxData["\<\"SubtractionTable[n, m] gives a table for n - m, for n > m > \
0, using the place value system. The integers are subtracted per digit \
position, and each underflow generates a new line in the table. If n < m then \
the routine switches the order. When subtracting a block of numbers, perhaps \
first add the numbers that must be subtracted, so that subtraction only \
applies to n - m\\nSubtractionTable[n__Integer] (for more than 2) or \
SubtractionTable[{n__Integer}] cannot switch the order though. Integers must \
be positive\\nOptions are passed on to ToSingleDigitsTable. Default there is \
Differences -> True (default); otherwise levels\\nWhen all integers are in \
[0, 9] then there is a warning that the routine is overly complex for such a \
case\"\>"], "Print", "PrintUsage",
 CellTags->
  "Info413734493367-1684409",ExpressionUUID->"09eee366-1c18-4bf2-9a88-\
795bdc037a72"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "MixedAdditionTable"}]], "Input",ExpressionUUID->"097eb51b-c5ee-4303-a571-0d38f6ec9a94"],

Cell[BoxData["\<\"MixedAdditionTable[n__Integer] (for more than 2) or \
MixedAdditionTable[{n__Integer}] adds positive or negative integers. Options \
are passed on to ToSingleDigitsTable. Default there is Differences -> True \
(default); otherwise levels\\nWhen all integers are in [0, 9] then there is a \
warning that the routine is overly complex for such a case\"\>"], "Print", \
"PrintUsage",
 CellTags->
  "Info423734493367-1684409",ExpressionUUID->"95de21c8-22d3-48e9-a2a6-\
a62555bd05a4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "ToSingleDigitsTable"}]], "Input",ExpressionUUID->"c039c656-ac97-4bf9-800c-ba9a10a90d91"],

Cell[BoxData["\<\"ToSingleDigitsTable[vec] decomposes the place value vector.\
\\nToSingleDigitsTable[\\\"Tested\\\", vec, table] complements the table. The \
test is on the proper length of vec for the table. The routine is called by \
AdditionTable, SubtractionTable and MixedAdditionTable for completion, and \
its option setting controls their output. Default option is Differences -> \
True; otherwise levels\"\>"], "Print", "PrintUsage",
 CellTags->
  "Info433734493367-1684409",ExpressionUUID->"064b2b82-b44e-44fb-813a-\
dae39b522ecd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "TableOfBasicAddition"}]], "Input",ExpressionUUID->"d0fd2f56-8dd7-4d63-ba10-b35bf02f0d2e"],

Cell[BoxData["\<\"TableOfBasicAddition[n:0, m:10] gives i + j in the range \
[n, m] for values Abs[i + j] <= Max[Abs[n], Abs[m]], and n and m may be \
negative. Elements x within the table show j = x - i. Options are passed on \
to TableForm\"\>"], "Print", "PrintUsage",
 CellTags->
  "Info443734493367-1684409",ExpressionUUID->"7c84b754-83e8-4705-ba56-\
fe1f879608cc"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". ",
 "Conclusions"
}], "Section",ExpressionUUID->"6736fb8b-0e51-4769-8f36-27f918ba2578"],

Cell["\<\
It is obviously advantageous when tables of addition and subtraction use the \
place value system in a better manner.\
\>", "Text",ExpressionUUID->"15bc5e6d-2588-483a-afb6-803f7b04e77f"],

Cell["\<\
The place value system by its very definition supports this way of working. \
It is rather amazing that this method has not been developed before, except \
for the addition in levels. Apparently overflow was recognised but underflow \
not, and this probably relates to the negative numbers.\
\>", "Text",ExpressionUUID->"f6a1d362-7f1d-428a-bc56-75925433db9b"],

Cell["\<\
The method fits in the current Common Core when we tell kids that a line with \
{1, -10} represents the subtraction 1 \[Times] 10 - 10 \[Times] 1 = 0, or \
with other appropriate values depending upon the positions.\
\>", "Text",ExpressionUUID->"f8207fa7-1e73-4d2c-ac4d-37466e551e25"],

Cell["\<\
Remarkably, the US Common Core has negative numbers only in Grade 6. See \
Colignatus (2018) for a fundamental discussion that it could be well better \
to have the negative integers in Grade 2 & 3, and only then start with \
fractions in Grade 4-6. First the whole numbers and place value system, and \
then the fractions.\
\>", "Text",ExpressionUUID->"2d1714bd-2a33-4000-9d6b-3a1ae10dea95"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". ",
 "Literature"
}], "Section",ExpressionUUID->"43cbb57c-b735-4ddf-b8a7-4659885e9ad6"],

Cell["\<\
Thomas Colignatus is the scientific name of Thomas Cool, econometrician and \
teacher of mathematics, Scheveningen, Holland.\
\>", "Text",ExpressionUUID->"025ac9ae-b2a7-4dc7-884f-23c5c08d1bf2"],

Cell[TextData[{
 "Colignatus, Th. (2014), ",
 StyleBox["Taking a loss",
  FontSlant->"Italic"],
 ", https://boycottholland.wordpress.com/2014/08/30/taking-a-loss/"
}], "Text",ExpressionUUID->"accb6d87-377e-4152-a20a-331484870af2"],

Cell[TextData[{
 "Colignatus, Th. (2009, 2015a), ",
 StyleBox["Elegance with Substance, \[LineSeparator]",
  FontSlant->"Italic"],
 "(1) website: http://thomascool.eu/Papers/Math/Index.html, \
\[LineSeparator](2) PDF on Zenodo: https://zenodo.org/record/291974, \
\[LineSeparator](3) Publisher for a print: \
https://www.mijnbestseller.nl/shop/index.php/catalog/product/view/id/115148/s/\
elegance-with-substance-78023-www-mijnbestseller-nl/"
}], "Text",ExpressionUUID->"c1618c00-aaab-4e90-af11-7374c37b2fb3"],

Cell[TextData[{
 "Colignatus, Th. (2015b),",
 StyleBox[" A child wants nice and no mean numbers",
  FontSlant->"Italic"],
 ", \[LineSeparator](1) website: \
http://thomascool.eu/Papers/NiceNumbers/Index.html\n(2) PDF on Zenodo: \
https://zenodo.org/record/291979\n(3) Publisher for a print: \
https://www.mijnbestseller.nl/shop/index.php/catalog/product/view/id/118082/s/\
a-child-wants-nice-and-no-mean-numbers-79074-www-mijnbestseller-nl/"
}], "Text",ExpressionUUID->"b76bade1-078b-4af7-a17c-112015191881"],

Cell[TextData[{
 "Colignatus, Th. (2018), ",
 StyleBox["Arithmetic with H = -1: subtraction, negative numbers, division, \
rationals and mixed numbers",
  FontSlant->"Italic"],
 ", update May 5, \
https://www.wolframcloud.com/objects/thomas-cool/MathEd/2018-04-02-Arithmetic-\
with-H.nb and http://community.wolfram.com/groups/-/m/t/1313408 (same links \
with updated files) or https://zenodo.org/record/1241383"
}], "Text",ExpressionUUID->"6c1ae86e-815e-4e45-a570-0ffc1502853d"],

Cell[TextData[{
 "Common Core Standards (2018), ",
 StyleBox["Number & Operations in Base Ten, ",
  FontSlant->"Italic"],
 "http://www.corestandards.org/Math/Content/NBT/ with also ",
 StyleBox["Understand place value",
  FontSlant->"Italic"]
}], "Text",ExpressionUUID->"98955075-68d9-4212-b9ed-598e049bd2ab"],

Cell[TextData[{
 "Everyday Mathematics (2018a), ",
 StyleBox["Alternative algorithms",
  FontSlant->"Italic"],
 ", \nhttp://everydaymath.uchicago.edu/parents/understanding-em/alternative-\
algorithms/"
}], "Text",ExpressionUUID->"17a61c53-e8b2-4830-bf0f-bfeeabe0f3d3"],

Cell[TextData[{
 "Everyday Mathematics (2018b), ",
 StyleBox["Addition - Partial Sums",
  FontSlant->"Italic"],
 ", http://everydaymath.uchicago.edu/teaching-topics/computation/add-partial-\
sums/"
}], "Text",ExpressionUUID->"b1f722fa-48e9-4ea1-b80a-602168a9a4b0"],

Cell[TextData[{
 "Everyday Mathematics (2018c), ",
 StyleBox["Partial Differences",
  FontSlant->"Italic"],
 ", \nhttp://everydaymath.uchicago.edu/teaching-topics/computation/sub-part-\
diff.html"
}], "Text",ExpressionUUID->"86b41f65-e3ee-4b0c-83f4-23baa611f607"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{716, 845},
WindowMargins->{{Automatic, 205}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{595.3199999999999, 841.92}},
FrontEndVersion->"11.2 for Microsoft Windows (64-bit) (September 11, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info403734493366-1684409"->{
  Cell[103808, 2912, 648, 10, 207, "Print",ExpressionUUID->"1952c713-b761-4009-b788-cba617ff3388",
   CellTags->"Info403734493366-1684409"]},
 "Info413734493367-1684409"->{
  Cell[104610, 2930, 904, 13, 276, "Print",ExpressionUUID->"09eee366-1c18-4bf2-9a88-795bdc037a72",
   CellTags->"Info413734493367-1684409"]},
 "Info423734493367-1684409"->{
  Cell[105670, 2951, 497, 8, 138, "Print",ExpressionUUID->"95de21c8-22d3-48e9-a2a6-a62555bd05a4",
   CellTags->"Info423734493367-1684409"]},
 "Info433734493367-1684409"->{
  Cell[106324, 2967, 542, 8, 138, "Print",ExpressionUUID->"064b2b82-b44e-44fb-813a-dae39b522ecd",
   CellTags->"Info433734493367-1684409"]},
 "Info443734493367-1684409"->{
  Cell[107024, 2983, 370, 6, 92, "Print",ExpressionUUID->"7c84b754-83e8-4705-ba56-fe1f879608cc",
   CellTags->"Info443734493367-1684409"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info403734493366-1684409", 112587, 3133},
 {"Info413734493367-1684409", 112760, 3136},
 {"Info423734493367-1684409", 112933, 3139},
 {"Info433734493367-1684409", 113105, 3142},
 {"Info443734493367-1684409", 113277, 3145}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[583, 22, 157, 2, 216, "Title",ExpressionUUID->"9d9298ae-42bb-4d91-83fa-9aae849dd2e6"],
Cell[743, 26, 153, 4, 78, "Text",ExpressionUUID->"6a77c6a2-b695-4f51-921d-1fd0dccb1a48"],
Cell[899, 32, 107, 0, 34, "Text",ExpressionUUID->"80e295ba-2beb-41b2-a15a-127c56b93040"],
Cell[1009, 34, 120, 1, 34, "Text",ExpressionUUID->"0b53733d-72a9-4178-b36a-041c26bdf534"],
Cell[1132, 37, 1580, 21, 342, "Text",ExpressionUUID->"5b53d446-c2c9-4903-852e-b01cb2ce59fb"],
Cell[2715, 60, 120, 1, 34, "Text",ExpressionUUID->"b32d6f50-f283-4760-8499-c7d1a15888dd"],
Cell[2838, 63, 229, 3, 56, "Text",ExpressionUUID->"24d19483-4d60-4bd0-9d51-75844fad6d97"],
Cell[3070, 68, 119, 1, 34, "Text",ExpressionUUID->"19e09a36-9bca-4349-af3d-051d8d1930ac"],
Cell[3192, 71, 130, 0, 34, "Text",ExpressionUUID->"d9c872a4-6194-49df-a529-ee063a5ed647"],
Cell[3325, 73, 117, 1, 34, "Text",ExpressionUUID->"14954c9b-e428-4ebb-9375-b9071453aabd"],
Cell[3445, 76, 120, 0, 34, "Text",ExpressionUUID->"502a014d-a95c-4f79-aed7-a99cf3c48de0"],
Cell[3568, 78, 220, 3, 56, "Text",ExpressionUUID->"8d148d52-8bfc-44ea-b899-050d53a53119"],
Cell[3791, 83, 235, 4, 56, "Text",ExpressionUUID->"773fe3fa-ea8c-45cf-8a67-3d3686958bf2"],
Cell[4029, 89, 149, 2, 34, "Text",ExpressionUUID->"5c9dc5de-7005-4cd8-909e-3a470e9dcaf3"],
Cell[CellGroupData[{
Cell[4203, 95, 85, 0, 53, "Subsection",ExpressionUUID->"966bcf2a-714b-4eaa-96df-f1d09eb69f56"],
Cell[4291, 97, 141, 4, 44, "Subsubsection",ExpressionUUID->"a097d6f4-5538-45e1-bf30-24ce731521d5"],
Cell[4435, 103, 139, 4, 36, "Subsubsection",ExpressionUUID->"ab58aed4-ee32-45b3-ba03-398f959a2f78"],
Cell[4577, 109, 154, 4, 36, "Subsubsection",ExpressionUUID->"20f5d55c-d057-42bd-8c4b-d017ad841dd8"],
Cell[4734, 115, 149, 4, 36, "Subsubsection",ExpressionUUID->"87d584a6-6c56-44d7-b9a1-f6e5855ba911"],
Cell[4886, 121, 149, 4, 36, "Subsubsection",ExpressionUUID->"605c6bb6-1c52-4df0-8b56-18e13805e4fb"],
Cell[5038, 127, 176, 4, 36, "Subsubsection",ExpressionUUID->"600b6c7d-ad10-46a0-93d2-f2e05b56c4a8"],
Cell[5217, 133, 165, 4, 36, "Subsubsection",ExpressionUUID->"9d0a6e8f-3e97-4a2e-bbf5-1d81907c3188"],
Cell[5385, 139, 177, 4, 36, "Subsubsection",ExpressionUUID->"6ed4aaf7-fd4f-4aab-b2a7-0532ae0129ae"],
Cell[5565, 145, 153, 4, 36, "Subsubsection",ExpressionUUID->"db4859f1-d16e-4d97-b498-5aaa31a66fc1"],
Cell[5721, 151, 141, 4, 36, "Subsubsection",ExpressionUUID->"5508aa4e-75a4-4711-aa07-8aaf78ca7067"],
Cell[5865, 157, 140, 4, 36, "Subsubsection",ExpressionUUID->"3e7adb97-6778-488b-aea3-990292d67e61"],
Cell[6008, 163, 139, 4, 36, "Subsubsection",ExpressionUUID->"36a4cd99-103c-466e-825e-3c72128cf995"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6184, 172, 127, 0, 53, "Subsection",ExpressionUUID->"38ffa996-0056-4372-9550-8e878fe08c99"],
Cell[6314, 174, 40259, 943, 5080, "Input",ExpressionUUID->"e72faa7e-a474-4c15-b174-e35193a67e2b",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[46610, 1122, 134, 5, 53, "Section",ExpressionUUID->"afb71b9a-4fe3-41bc-95a2-c0fad96dad06"],
Cell[46747, 1129, 335, 5, 78, "Text",ExpressionUUID->"190fee63-4808-43b2-87f1-2f662ead2769"],
Cell[47085, 1136, 426, 14, 56, "Text",ExpressionUUID->"e9b8de4b-9f1b-4d03-a053-d6a361c57376"],
Cell[47514, 1152, 435, 6, 100, "Text",ExpressionUUID->"563ef84c-1bf5-478d-86fa-ffa8faf3b54c"],
Cell[47952, 1160, 292, 4, 78, "Text",ExpressionUUID->"39b6e25f-f0cf-44bb-8865-560679c1645a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48281, 1169, 132, 5, 67, "Section",ExpressionUUID->"45cc9238-2ce2-49f0-a845-253393dd887a"],
Cell[CellGroupData[{
Cell[48438, 1178, 170, 7, 53, "Subsection",ExpressionUUID->"838b2551-294e-409d-94b0-7ef1a04f3c6a"],
Cell[48611, 1187, 162, 3, 34, "Text",ExpressionUUID->"84764276-6bdf-4714-86e8-e8db818c6a98"],
Cell[CellGroupData[{
Cell[48798, 1194, 109, 0, 31, "Item",ExpressionUUID->"0179f9df-e6aa-4ad3-b76f-a99f77d099a5"],
Cell[48910, 1196, 167, 3, 31, "Item",ExpressionUUID->"cef8fe4f-9880-46fb-8c75-214fdaca64f9"],
Cell[49080, 1201, 180, 3, 51, "Item",ExpressionUUID->"9b1779ae-1fa7-4b4b-9549-b752935199f1"],
Cell[49263, 1206, 141, 2, 31, "Item",ExpressionUUID->"bdaa25f0-b06a-4c64-be78-0890f9b9811b"]
}, Open  ]],
Cell[49419, 1211, 329, 5, 78, "Text",ExpressionUUID->"c132a97c-ab2b-4054-a66f-7c547f2ce162"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49785, 1221, 173, 7, 53, "Subsection",ExpressionUUID->"44e457a3-0e25-4906-a7c6-1b15e0ca3c7f"],
Cell[49961, 1230, 206, 3, 56, "Text",ExpressionUUID->"79210a19-4f89-4de6-bb4a-a80dca020421"],
Cell[CellGroupData[{
Cell[50192, 1237, 193, 4, 28, "Input",ExpressionUUID->"ed4357f3-f103-4026-8208-079a8ec714d8"],
Cell[50388, 1243, 114, 1, 32, "Output",ExpressionUUID->"1dce4bfc-39df-4ce7-9447-591734e05683"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50539, 1249, 198, 4, 28, "Input",ExpressionUUID->"23b97f51-6785-462a-9b39-d1185649752c"],
Cell[50740, 1255, 1742, 49, 137, "Output",ExpressionUUID->"c356cd79-fcac-4a4f-b892-4c2952d7e3a1"]
}, Open  ]],
Cell[52497, 1307, 257, 4, 56, "Text",ExpressionUUID->"7ec6f833-9ead-4efd-9b70-b0fafbb07c8a"],
Cell[CellGroupData[{
Cell[52779, 1315, 321, 8, 28, "Input",ExpressionUUID->"aa059220-c485-45e1-baaf-2f69ff80356e"],
Cell[53103, 1325, 194, 6, 32, "Output",ExpressionUUID->"187913e5-5d6f-461a-aecc-62f9b4222ef4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53334, 1336, 191, 4, 28, "Input",ExpressionUUID->"ae8755ed-25e8-4a89-b328-504916b5098b"],
Cell[53528, 1342, 111, 1, 32, "Output",ExpressionUUID->"968b34d5-8db4-421d-a2be-5c61a5fd7c1e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[53688, 1349, 185, 7, 53, "Subsection",ExpressionUUID->"30be3da7-e3ec-4261-8977-2374a3479793"],
Cell[53876, 1358, 422, 6, 100, "Text",ExpressionUUID->"c6f25e63-b09a-4fce-b9d1-db1f688b8110"],
Cell[54301, 1366, 192, 3, 56, "Text",ExpressionUUID->"69876556-24d4-4a1e-bc4d-4462ca685ca6"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[54542, 1375, 147, 5, 67, "Section",ExpressionUUID->"1e6454b0-512d-4327-b831-bade222e281f"],
Cell[54692, 1382, 150, 2, 34, "Text",ExpressionUUID->"904abfcb-cbed-4ee9-9b65-eae1a1bb1a31"],
Cell[54845, 1386, 189, 3, 56, "Text",ExpressionUUID->"78fad10e-f392-426c-9b47-34403f38d568"],
Cell[55037, 1391, 220, 3, 56, "Text",ExpressionUUID->"02764c54-de18-4b21-9359-64b139632322"],
Cell[CellGroupData[{
Cell[55282, 1398, 153, 3, 28, "Input",ExpressionUUID->"91878eff-e5f4-4aee-a65b-a11f2ea824b3"],
Cell[55438, 1403, 1629, 46, 171, "Output",ExpressionUUID->"b39fc6ec-f044-4cf1-bfad-724ec900e4ae"]
}, Open  ]],
Cell[57082, 1452, 500, 7, 122, "Text",ExpressionUUID->"b073486a-ff71-4c6c-b49d-09bfcbb74787"],
Cell[57585, 1461, 125, 0, 34, "Text",ExpressionUUID->"b4179950-d67a-439d-87c3-0408a0777bee"],
Cell[CellGroupData[{
Cell[57735, 1465, 172, 3, 28, "Input",ExpressionUUID->"a5b6c659-0f4f-41f5-a08b-9e437f028ea8"],
Cell[57910, 1470, 1908, 53, 205, "Output",ExpressionUUID->"984872d3-3ad8-4119-8d99-3b41ca8a76d7"]
}, Open  ]],
Cell[59833, 1526, 244, 4, 56, "Text",ExpressionUUID->"68f5a330-6194-44bc-92e1-8ca512a7a31b"],
Cell[CellGroupData[{
Cell[60102, 1534, 158, 3, 28, "Input",ExpressionUUID->"bd6ed29a-1975-4846-a466-112be3ab5ec9"],
Cell[60263, 1539, 409, 8, 21, "Message",ExpressionUUID->"a0f77b4d-1a1c-419d-8b6e-fd9e2f91c508"],
Cell[60675, 1549, 1591, 45, 154, "Output",ExpressionUUID->"3c963dca-2be3-452f-9e84-0f1e14d15eb9"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[62315, 1600, 142, 5, 67, "Section",ExpressionUUID->"ddcec3bc-74aa-425b-bc30-e588be5aefec"],
Cell[62460, 1607, 156, 2, 34, "Text",ExpressionUUID->"01089270-0d80-423c-b377-83d6e681b832"],
Cell[62619, 1611, 396, 6, 78, "Text",ExpressionUUID->"77e46a05-e83c-45cc-a58c-1b36a1e1ab0e"],
Cell[CellGroupData[{
Cell[63040, 1621, 222, 4, 28, "Input",ExpressionUUID->"61f4be85-67a1-4ca6-8720-697b9a786202"],
Cell[63265, 1627, 1488, 42, 137, "Output",ExpressionUUID->"ca307bf2-9bc7-425c-8c1c-5d3c1829f532"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64790, 1674, 241, 4, 28, "Input",ExpressionUUID->"14c33dc2-bbc4-48c5-9c62-b7507291f523"],
Cell[65034, 1680, 1698, 48, 171, "Output",ExpressionUUID->"52ca3859-4319-4c1b-8613-3f5a0c1af8b4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66769, 1733, 227, 4, 28, "Input",ExpressionUUID->"f0774834-0677-4d2e-9bc5-79945126653b"],
Cell[66999, 1739, 1480, 42, 120, "Output",ExpressionUUID->"09331434-2eed-4c07-882b-8a0750b10478"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[68528, 1787, 142, 5, 67, "Section",ExpressionUUID->"b8d4db93-5dc9-4cdf-9b8a-23a66988bb03"],
Cell[68673, 1794, 124, 0, 34, "Text",ExpressionUUID->"167c239c-58c7-4387-9c6f-35ffaee71eb6"],
Cell[CellGroupData[{
Cell[68822, 1798, 189, 3, 51, "Item",ExpressionUUID->"1d938329-0bda-48d5-8061-52e37522aa8a"],
Cell[69014, 1803, 360, 5, 71, "Item",ExpressionUUID->"14ed5d23-8bb8-4df9-819d-c23f734ff7c9"],
Cell[69377, 1810, 277, 4, 71, "Item",ExpressionUUID->"a3bf8940-2ca8-4d3e-b004-e9c824fb0af0"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[69703, 1820, 164, 4, 67, "Section",ExpressionUUID->"0fada0b1-808b-4dda-863a-d5da4718fa61"],
Cell[69870, 1826, 243, 4, 56, "Text",ExpressionUUID->"a3bff7f2-6310-4090-9d42-43027e89051e"],
Cell[CellGroupData[{
Cell[70138, 1834, 195, 4, 28, "Input",ExpressionUUID->"b09bae3e-429e-4e3a-86a0-1ee77b3f5dbe"],
Cell[70336, 1840, 1506, 45, 171, "Output",ExpressionUUID->"cb9e2a40-6111-48ae-afdd-d209e962234d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71879, 1890, 180, 4, 28, "Input",ExpressionUUID->"bed72455-3ec1-4884-82aa-3f3767c70245"],
Cell[72062, 1896, 1459, 43, 137, "Output",ExpressionUUID->"c8e8112f-22f0-4e0a-b7f2-376a79b44be1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73558, 1944, 172, 3, 28, "Input",ExpressionUUID->"e2a4c71f-a630-4b9d-8de7-b3cab5f13431"],
Cell[73733, 1949, 1772, 52, 188, "Output",ExpressionUUID->"e9115a16-f7bc-4f7b-aacd-9e6df4b4ebde"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75542, 2006, 190, 3, 28, "Input",ExpressionUUID->"61c6c51a-5b59-4d8e-9880-62ee78504171"],
Cell[75735, 2011, 1730, 50, 205, "Output",ExpressionUUID->"5c4461be-04dd-4b89-a9c0-8711d6fd3f82"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[77514, 2067, 158, 5, 67, "Section",ExpressionUUID->"b0d2a19b-a80e-4e8d-b66c-3bbb56831cd4"],
Cell[77675, 2074, 343, 5, 78, "Text",ExpressionUUID->"74bc7233-136c-4d78-bb8b-926119cbc629"],
Cell[CellGroupData[{
Cell[78043, 2083, 166, 3, 28, "Input",ExpressionUUID->"7cd7361a-cdc9-4557-b5da-4cd45789e2e9"],
Cell[78212, 2088, 331, 7, 21, "Message",ExpressionUUID->"79cddb8b-34a6-4eb6-a308-60f8c760ced5"],
Cell[78546, 2097, 1438, 42, 171, "Output",ExpressionUUID->"122b6bbe-cac1-4e78-9fac-22e7177f24ac"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80021, 2144, 184, 3, 28, "Input",ExpressionUUID->"74057ed2-5a72-4445-95b9-8c26e8896290"],
Cell[80208, 2149, 337, 7, 21, "Message",ExpressionUUID->"4c1b3e74-5003-4872-bd13-fc9112c6f2af"],
Cell[80548, 2158, 1507, 45, 188, "Output",ExpressionUUID->"a4a82cde-0e1f-416a-8fd3-15e41fafebbb"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[82104, 2209, 170, 5, 105, "Section",ExpressionUUID->"0f19e7d6-cc1b-4204-b07a-73e55a01788d"],
Cell[CellGroupData[{
Cell[82299, 2218, 185, 7, 53, "Subsection",ExpressionUUID->"f1f69fdf-2f3c-4873-9230-4e5b3592dd52"],
Cell[CellGroupData[{
Cell[82509, 2229, 218, 10, 44, "Subsubsection",ExpressionUUID->"4ce7bf8e-4b50-403c-b8fe-c4195e306115"],
Cell[82730, 2241, 285, 4, 78, "Text",ExpressionUUID->"56d10f1d-b058-46f5-9a4c-67854beffa97"],
Cell[83018, 2247, 228, 3, 56, "Text",ExpressionUUID->"1b142138-6251-4ec5-95aa-7ded2c61de86"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83283, 2255, 230, 10, 44, "Subsubsection",ExpressionUUID->"85a064f5-9a5c-46ce-a7d1-b0095a306553"],
Cell[83516, 2267, 424, 10, 78, "Text",ExpressionUUID->"da834444-5aa4-40fe-b778-b624c8accac2"],
Cell[CellGroupData[{
Cell[83965, 2281, 230, 3, 51, "Item",ExpressionUUID->"8f3a34c5-4f54-46fa-a8f8-ead02ba0c273"],
Cell[84198, 2286, 147, 2, 31, "Item",ExpressionUUID->"8e6d35c8-7d86-4d52-81f0-b8b195b2699c"],
Cell[84348, 2290, 246, 4, 51, "Item",ExpressionUUID->"cc2cc15f-1678-4ebf-a0a0-9acf76d3f513"],
Cell[84597, 2296, 165, 3, 31, "Item",ExpressionUUID->"24dfa176-7113-4436-ad7f-d64764df37c5"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[84823, 2306, 197, 7, 53, "Subsection",ExpressionUUID->"6e8e2f51-d505-4a0a-b3bf-37e24f507a00"],
Cell[85023, 2315, 458, 8, 100, "Text",ExpressionUUID->"0ad7f4a2-ed36-42e6-87e0-0c1bad238e32"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85518, 2328, 202, 7, 53, "Subsection",ExpressionUUID->"7f25e13e-16d4-4645-bdc6-6ef0b8ea84f4"],
Cell[85723, 2337, 971, 18, 188, "Text",ExpressionUUID->"8662654b-5b05-447f-808f-51936e7c816f"],
Cell[CellGroupData[{
Cell[86719, 2359, 212, 5, 28, "Input",ExpressionUUID->"5afcdb3f-e3f6-479d-ad34-c7164a435648"],
Cell[86934, 2366, 1747, 51, 188, "Output",ExpressionUUID->"b0e82216-2324-4c0c-976c-24503bb8891e"]
}, Open  ]],
Cell[88696, 2420, 400, 8, 78, "Text",ExpressionUUID->"890eeed1-888e-4b21-9a50-2d1dd67d1090"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[89145, 2434, 146, 5, 67, "Section",ExpressionUUID->"bf566b93-9dae-4724-8435-96055ed8138f"],
Cell[CellGroupData[{
Cell[89316, 2443, 175, 7, 53, "Subsection",ExpressionUUID->"c8e33fa7-48c3-4342-bc5e-6b537fd8dd3a"],
Cell[89494, 2452, 296, 4, 78, "Text",ExpressionUUID->"5960ca4e-bc4e-4f1c-b098-28979fcf3988"],
Cell[CellGroupData[{
Cell[89815, 2460, 227, 5, 28, "Input",ExpressionUUID->"cc04dde6-ecd0-4f03-a30b-c233c36c73c6"],
Cell[90045, 2467, 1552, 47, 188, "Output",ExpressionUUID->"5fd4f9bf-e06f-4664-8a44-8d29915739b4"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[91646, 2520, 193, 7, 53, "Subsection",ExpressionUUID->"abe02bb0-707d-4d42-b0c4-1e1f278d5c68"],
Cell[91842, 2529, 601, 10, 100, "Text",ExpressionUUID->"494019ec-126f-460d-ba42-384c67e75a0b"],
Cell[92446, 2541, 278, 4, 56, "Text",ExpressionUUID->"35c79d64-88d1-4a9c-bf8d-2dd669a19f19"],
Cell[CellGroupData[{
Cell[92749, 2549, 123, 1, 28, "Input",ExpressionUUID->"ae2b2bb4-2414-499c-9e81-8079374cee48"],
Cell[92875, 2552, 3109, 98, 219, "Output",ExpressionUUID->"3e09222a-4b94-42a7-a58e-414f614d80f1"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[96033, 2656, 193, 7, 53, "Subsection",ExpressionUUID->"c8876381-8740-4cd4-8e67-c54cb2ca3e04"],
Cell[96229, 2665, 116, 0, 34, "Text",ExpressionUUID->"7df6dae7-036c-433b-93b6-e80c2e976514"],
Cell[CellGroupData[{
Cell[96370, 2669, 177, 4, 28, "Input",ExpressionUUID->"6739be70-e7d9-4b65-b0cc-e04e91436bad"],
Cell[96550, 2675, 4034, 137, 219, "Output",ExpressionUUID->"2fb8c63f-6f35-429d-8f3f-aa997f24567e"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[100645, 2819, 134, 5, 67, "Section",ExpressionUUID->"db23e7cc-a8f3-4f19-b9a8-2f9cd6511ff4"],
Cell[CellGroupData[{
Cell[100804, 2828, 125, 1, 28, "Input",ExpressionUUID->"9648044f-a802-4708-8e09-aa68967a08bf"],
Cell[100932, 2831, 2725, 73, 102, "Print",ExpressionUUID->"43923a7f-f65d-4200-bb2c-beb9f6695313"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103694, 2909, 111, 1, 28, "Input",ExpressionUUID->"10aa7b44-5d5b-460d-a393-98704ebdcec5"],
Cell[103808, 2912, 648, 10, 207, "Print",ExpressionUUID->"1952c713-b761-4009-b788-cba617ff3388",
 CellTags->"Info403734493366-1684409"]
}, Open  ]],
Cell[CellGroupData[{
Cell[104493, 2927, 114, 1, 28, "Input",ExpressionUUID->"34ba3f25-4f23-4ed4-a7b5-b202397c3e6e"],
Cell[104610, 2930, 904, 13, 276, "Print",ExpressionUUID->"09eee366-1c18-4bf2-9a88-795bdc037a72",
 CellTags->"Info413734493367-1684409"]
}, Open  ]],
Cell[CellGroupData[{
Cell[105551, 2948, 116, 1, 28, "Input",ExpressionUUID->"097eb51b-c5ee-4303-a571-0d38f6ec9a94"],
Cell[105670, 2951, 497, 8, 138, "Print",ExpressionUUID->"95de21c8-22d3-48e9-a2a6-a62555bd05a4",
 CellTags->"Info423734493367-1684409"]
}, Open  ]],
Cell[CellGroupData[{
Cell[106204, 2964, 117, 1, 28, "Input",ExpressionUUID->"c039c656-ac97-4bf9-800c-ba9a10a90d91"],
Cell[106324, 2967, 542, 8, 138, "Print",ExpressionUUID->"064b2b82-b44e-44fb-813a-dae39b522ecd",
 CellTags->"Info433734493367-1684409"]
}, Open  ]],
Cell[CellGroupData[{
Cell[106903, 2980, 118, 1, 28, "Input",ExpressionUUID->"d0fd2f56-8dd7-4d63-ba10-b35bf02f0d2e"],
Cell[107024, 2983, 370, 6, 92, "Print",ExpressionUUID->"7c84b754-83e8-4705-ba56-fe1f879608cc",
 CellTags->"Info443734493367-1684409"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[107443, 2995, 133, 5, 67, "Section",ExpressionUUID->"6736fb8b-0e51-4769-8f36-27f918ba2578"],
Cell[107579, 3002, 196, 3, 56, "Text",ExpressionUUID->"15bc5e6d-2588-483a-afb6-803f7b04e77f"],
Cell[107778, 3007, 369, 5, 78, "Text",ExpressionUUID->"f6a1d362-7f1d-428a-bc56-75925433db9b"],
Cell[108150, 3014, 294, 4, 56, "Text",ExpressionUUID->"f8207fa7-1e73-4d2c-ac4d-37466e551e25"],
Cell[108447, 3020, 402, 6, 100, "Text",ExpressionUUID->"2d1714bd-2a33-4000-9d6b-3a1ae10dea95"]
}, Open  ]],
Cell[CellGroupData[{
Cell[108886, 3031, 132, 5, 67, "Section",ExpressionUUID->"43cbb57c-b735-4ddf-b8a7-4659885e9ad6"],
Cell[109021, 3038, 203, 3, 56, "Text",ExpressionUUID->"025ac9ae-b2a7-4dc7-884f-23c5c08d1bf2"],
Cell[109227, 3043, 230, 5, 56, "Text",ExpressionUUID->"accb6d87-377e-4152-a20a-331484870af2"],
Cell[109460, 3050, 509, 9, 144, "Text",ExpressionUUID->"c1618c00-aaab-4e90-af11-7374c37b2fb3"],
Cell[109972, 3061, 508, 9, 144, "Text",ExpressionUUID->"b76bade1-078b-4af7-a17c-112015191881"],
Cell[110483, 3072, 479, 9, 100, "Text",ExpressionUUID->"6c1ae86e-815e-4e45-a570-0ffc1502853d"],
Cell[110965, 3083, 309, 7, 56, "Text",ExpressionUUID->"98955075-68d9-4212-b9ed-598e049bd2ab"],
Cell[111277, 3092, 268, 6, 56, "Text",ExpressionUUID->"17a61c53-e8b2-4830-bf0f-bfeeabe0f3d3"],
Cell[111548, 3100, 264, 6, 56, "Text",ExpressionUUID->"b1f722fa-48e9-4ea1-b80a-602168a9a4b0"],
Cell[111815, 3108, 263, 6, 56, "Text",ExpressionUUID->"86b41f65-e3ee-4b0c-83f4-23baa611f607"]
}, Open  ]]
}, Open  ]]
}
]
*)

